@@ -113,6 +113,11 @@ enum ItemRoles {
     kItemTreeViewCanExpandRole = Qt::UserRole + 36,   // item can expand
     kItemUpdateAndTransFileInfoRole = Qt::UserRole + 37,
     kItemFileContentPreviewRole = Qt::UserRole + 38,   // item file content
+    kItemIsGroupHeaderType = Qt::UserRole + 39,
+    kItemGroupHeaderKey = Qt::UserRole + 40,
+    kItemGroupDisplayIndex = Qt::UserRole + 41,
+    kItemGroupExpandedRole = Qt::UserRole + 42,
+    kItemGroupFileCount = Qt::UserRole + 43,
     kItemUnknowRole = Qt::UserRole + 999
 };
 
