@@ -110,11 +110,9 @@ static bool pluginsLoad()
 
 static void handleSIGTERM(int sig)
 {
-    qCWarning(logAppDaemon) << "handleSIGTERM: Received SIGTERM signal:" << sig;
-
+    // 这里处理时不能有任何的内存分配，可能会出现卡死，或者崩溃
     if (qApp) {
-        // 重启或关闭系统时，信号处理会阻塞进程
-        QTimer::singleShot(0, qApp, &QApplication::quit);
+        qApp->quit();
     }
 }
 
