@@ -27,8 +27,9 @@ DWIDGET_USE_NAMESPACE
 
 #define TOP_GROUP_BASE "00_base"
 #define LV2_GROUP_OPEN_ACTION "00_base.00_open_action"
-#define LV2_GROUP_NEW_TAB_WINDOWS "00_base.01_new_tab_windows"
-#define LV2_GROUP_FILES_AND_FOLDERS "00_base.02_files_and_folders"
+#define LV2_GROUP_NEW_WINDOWS "00_base.01_new_windows"
+#define LV2_GROUP_NEW_TAB "00_base.02_new_tab"
+#define LV2_GROUP_FILES_AND_FOLDERS "00_base.03_files_and_folders"
 
 #define TOP_GROUP_WORKSPACE "02_workspace"
 #define LV2_GROUP_VIEW "02_workspace.00_view"
@@ -41,9 +42,10 @@ DWIDGET_USE_NAMESPACE
 
 BidirectionHash<QString, Application::ApplicationAttribute> SettingBackendPrivate::keyToAA {
     { LV2_GROUP_OPEN_ACTION ".00_allways_open_on_new_window", Application::kAllwayOpenOnNewWindow },
-    { LV2_GROUP_OPEN_ACTION ".02_open_file_action", Application::kOpenFileMode },
-    { LV2_GROUP_NEW_TAB_WINDOWS ".00_default_window_path", Application::kUrlOfNewWindow },
-    { LV2_GROUP_NEW_TAB_WINDOWS ".01_new_tab_path", Application::kUrlOfNewTab },
+    { LV2_GROUP_OPEN_ACTION ".01_open_in_new_tab", Application::kOpenInNewTab },
+    { LV2_GROUP_OPEN_ACTION ".03_open_file_action", Application::kOpenFileMode },
+    { LV2_GROUP_NEW_WINDOWS ".01_default_window_path", Application::kUrlOfNewWindow },
+    { LV2_GROUP_NEW_TAB ".01_new_tab_path", Application::kUrlOfNewTab },
     { LV2_GROUP_VIEW ".00_icon_size", Application::kIconSizeLevel },
     { LV2_GROUP_VIEW ".01_icon_grid_density", Application::kGridDensityLevel },
     { LV2_GROUP_VIEW ".02_list_height", Application::kListHeightLevel },
@@ -144,7 +146,7 @@ void SettingBackend::addSettingAccessor(const QString &key, GetOptFunc get, Save
         d->getters.insert(key, get);
     else
         qCWarning(logDFMBase) << "Null getter function provided for setting key:" << key;
-    
+
     qCDebug(logDFMBase) << "Setting accessor added for key:" << key;
 }
 
@@ -243,11 +245,14 @@ void SettingBackend::initBasicSettingConfig()
     ins->addCheckBoxConfig(LV2_GROUP_OPEN_ACTION ".00_allways_open_on_new_window",
                            tr("Always open folder in new window"),
                            false);
-    ins->addCheckBoxConfig(LV2_GROUP_OPEN_ACTION ".01_open_folder_windows_in_aseparate_process",
+    ins->addCheckBoxConfig(LV2_GROUP_OPEN_ACTION ".01_open_in_new_tab",
+                           tr("Open new folder in a new tab"),
+                           false);
+    ins->addCheckBoxConfig(LV2_GROUP_OPEN_ACTION ".02_open_folder_windows_in_aseparate_process",
                            tr("Activate existing window when reopening folder"),
                            false);
     addSettingAccessor(
-            LV2_GROUP_OPEN_ACTION ".01_open_folder_windows_in_aseparate_process",
+            LV2_GROUP_OPEN_ACTION ".02_open_folder_windows_in_aseparate_process",
             []() {
                 return !(DConfigManager::instance()->value(kViewDConfName,
                                                            kOpenFolderWindowsInASeparateProcess,
@@ -259,36 +264,42 @@ void SettingBackend::initBasicSettingConfig()
                                                      kOpenFolderWindowsInASeparateProcess,
                                                      !(val.toBool()));
             });
-    ins->addComboboxConfig(LV2_GROUP_OPEN_ACTION ".02_open_file_action",
+    ins->addComboboxConfig(LV2_GROUP_OPEN_ACTION ".03_open_file_action",
                            tr("Open file:"),
                            QStringList { tr("Click"),
                                          tr("Double click") },
                            1);
 
     // base / new_win_and_tab
-    ins->addGroup(LV2_GROUP_NEW_TAB_WINDOWS, tr("New window and tab"));
-    ins->addComboboxConfig(LV2_GROUP_NEW_TAB_WINDOWS ".00_default_window_path",
-                           tr("Open from default window:"),
-                           { { "values",
-                               QStringList { tr("Computer"),
-                                             tr("Home"),
-                                             tr("Desktop"),
-                                             tr("Videos"),
-                                             tr("Music"),
-                                             tr("Pictures"),
-                                             tr("Documents"),
-                                             tr("Downloads") } },
-                             { "keys",
-                               QStringList { "computer:///",
-                                             "standard://home",
-                                             "standard://desktop",
-                                             "standard://videos",
-                                             "standard://music",
-                                             "standard://pictures",
-                                             "standard://documents",
-                                             "standard://downloads" } } },
-                           "computer:///");
-    ins->addComboboxConfig(LV2_GROUP_NEW_TAB_WINDOWS ".01_new_tab_path",
+    ins->addGroup(LV2_GROUP_NEW_WINDOWS, tr("New window"));
+    ins->addConfig(LV2_GROUP_NEW_WINDOWS ".00_message_label",
+                   { { "key", "00_message_label" },
+                     { "name", tr("Display when launching a new window:") },
+                     { "type", "label" } });
+    ins->addPathComboboxConfig(LV2_GROUP_NEW_WINDOWS ".01_default_window_path",
+                   tr("Default Directory"),
+                   { { "values",
+                       QStringList { tr("Computer"),
+                                     tr("Home"),
+                                     tr("Desktop"),
+                                     tr("Videos"),
+                                     tr("Music"),
+                                     tr("Pictures"),
+                                     tr("Documents"),
+                                     tr("Downloads") } },
+                     { "keys",
+                       QStringList { "computer:///",
+                                     "standard://home",
+                                     "standard://desktop",
+                                     "standard://videos",
+                                     "standard://music",
+                                     "standard://pictures",
+                                     "standard://documents",
+                                     "standard://downloads" } } },
+                   "computer:///");
+
+    ins->addGroup(LV2_GROUP_NEW_TAB, tr("New tab"));
+    ins->addComboboxConfig(LV2_GROUP_NEW_TAB ".01_new_tab_path",
                            tr("Open in new tab:"),
                            { { "values",
                                QStringList { tr("Current Directory"),
@@ -335,33 +346,33 @@ void SettingBackend::initWorkspaceSettingConfig()
     int iconSizeLevelMax = viewDefines.iconSizeCount() - 1;
     int iconSizeLevelMin = 0;
     ins->addSliderConfig(LV2_GROUP_VIEW ".00_icon_size",
-                        tr("Default icon size:"),
-                        "dfm_viewoptions_minicon",
-                        "dfm_viewoptions_maxicon",
-                        iconSizeLevelMax,
-                        iconSizeLevelMin,
-                        viewDefines.getIconSizeList(),
-                        5);
+                         tr("Default icon size:"),
+                         "dfm_viewoptions_minicon",
+                         "dfm_viewoptions_maxicon",
+                         iconSizeLevelMax,
+                         iconSizeLevelMin,
+                         viewDefines.getIconSizeList(),
+                         5);
     int iconGridDensityLevelMax = viewDefines.iconGridDensityCount() - 1;
     int iconGridDensityLevelMin = 0;
     ins->addSliderConfig(LV2_GROUP_VIEW ".01_icon_grid_density",
-                        tr("Default icon grid density:"),
-                        "dfm_viewoptions_mingrid",
-                        "dfm_viewoptions_maxgrid",
-                        iconGridDensityLevelMax,
-                        iconGridDensityLevelMin,
-                        viewDefines.getIconGridDensityList(),
-                        2);
+                         tr("Default icon grid density:"),
+                         "dfm_viewoptions_mingrid",
+                         "dfm_viewoptions_maxgrid",
+                         iconGridDensityLevelMax,
+                         iconGridDensityLevelMin,
+                         viewDefines.getIconGridDensityList(),
+                         2);
     int listHeightLevelMax = viewDefines.listHeightCount() - 1;
     int listHeightLevelMin = 0;
     ins->addSliderConfig(LV2_GROUP_VIEW ".02_list_height",
-                        tr("Default list height:"),
-                        "dfm_viewoptions_minlist",
-                        "dfm_viewoptions_maxlist",
-                        listHeightLevelMax,
-                        listHeightLevelMin,
-                        viewDefines.getListHeightList(),
-                        1);
+                         tr("Default list height:"),
+                         "dfm_viewoptions_minlist",
+                         "dfm_viewoptions_maxlist",
+                         listHeightLevelMax,
+                         listHeightLevelMin,
+                         viewDefines.getListHeightList(),
+                         1);
     QStringList viewModeValues { tr("Icon"), tr("List") };
     QVariantList viewModeKeys { 1, 2 };
     if (DConfigManager::instance()->value(kViewDConfName, kTreeViewEnable, true).toBool()) {
