@@ -48,6 +48,11 @@ static constexpr char kDaemonMountIface[] { "org.deepin.Filemanager.MountControl
 static constexpr char kDaemonIntroIface[] { "org.freedesktop.DBus.Introspectable" };
 static constexpr char kDaemonIntroMethod[] { "Introspect" };
 
+// DLNFS service constants
+static constexpr char kDlnfsService[] { "org.deepin.dlnfs.Control" };
+static constexpr char kDlnfsPath[] { "/org/deepin/dlnfs/Control" };
+static constexpr char kDlnfsIface[] { "org.deepin.dlnfs.Control" };
+
 DeviceManager *DeviceManager::instance()
 {
     static DeviceManager ins;
@@ -794,9 +799,9 @@ void DeviceManager::doAutoMountAtStart()
     }
 
     static std::once_flag flg;
-    std::call_once(flg, [this] { 
+    std::call_once(flg, [this] {
         qCInfo(logDFMBase) << "Starting auto mount process at application startup";
-        d->mountAllBlockDev(); 
+        d->mountAllBlockDev();
     });
 }
 
@@ -1064,8 +1069,10 @@ void DeviceManagerPrivate::handleDlnfsMount(const QString &mpt, bool mount)
         }
     }
 
-    if (!isDaemonMountRunning()) {
-        qCWarning(logDFMBase) << "DLNFS daemon mount service is not available";
+    // Check if DLNFS service is available
+    QDBusConnectionInterface *systemBusIFace = QDBusConnection::systemBus().interface();
+    if (!systemBusIFace->isServiceRegistered(kDlnfsService)) {
+        qCWarning(logDFMBase) << "DLNFS service is not available:" << kDlnfsService;
         return;
     }
 
@@ -1073,7 +1080,7 @@ void DeviceManagerPrivate::handleDlnfsMount(const QString &mpt, bool mount)
 
     qCInfo(logDFMBase) << "Starting DLNFS" << method.toLower() << "operation for mount point:" << mpt;
 
-    QDBusInterface iface(kDaemonService, kDaemonMountPath, kDaemonMountIface, QDBusConnection::systemBus());
+    QDBusInterface iface(kDlnfsService, kDlnfsPath, kDlnfsIface, QDBusConnection::systemBus());
     QDBusReply<QVariantMap> reply = iface.call(method, mpt, QVariantMap { { "fsType", "dlnfs" } });
     const auto &ret = reply.value();
 
@@ -1086,11 +1093,14 @@ void DeviceManagerPrivate::handleDlnfsMount(const QString &mpt, bool mount)
 
 void DeviceManagerPrivate::unmountStackedMount(const QString &mpt)
 {
+    // TODO: Not sure what this code does, will look at it when something goes wrong
+#if 0
     QDBusInterface iface(kDaemonService, kDaemonMountPath, kDaemonMountIface, QDBusConnection::systemBus());
     QDBusReply<QVariantMap> reply = iface.call("Unmount", mpt,
                                                QVariantMap { { "fsType", "common" }, { "unmountAllStacked", true } });
     const auto &ret = reply.value();
     qCDebug(logDFMBase) << "unmount all stacked mount of: " << mpt << ret;
+#endif
 }
 
 MountPassInfo DeviceManagerPrivate::askForPasswdWhenMountNetworkDevice(const QString &message, const QString &userDefault,
