@@ -55,6 +55,8 @@ public:
     // device signals
 Q_SIGNALS:
     void devSizeChanged(const QString &id, qint64 total, qint64 avai);
+    void mountPointAboutToAdded(QStringView mpt);
+    void mountPointAboutToRemoved(QStringView mpt);
 
     void blockDevPropertyChanged(const QString &id, const QString &property, const QVariant &val);
     void blockDriveAdded();
