@@ -24,10 +24,9 @@
 DWIDGET_USE_NAMESPACE
 using namespace dfmbase;
 
-static constexpr int kMsgLabelWidth { 390 };
-static constexpr int kMsgLabelHoverWidth { 460 };
+static constexpr int kMsgLabelWidth { 468 };
 static constexpr int kSpeedLabelWidth { 100 };
-static constexpr uint8_t kVirtualValue { 30 };
+static constexpr int kFileSizeWidth { 100 };
 static constexpr char kBtnPropertyActionName[] { "btnType" };
 static constexpr AbstractJobHandler::JobState kPausedState = AbstractJobHandler::JobState::kPauseState;
 
@@ -36,7 +35,7 @@ ElidedLable::ElidedLable(QWidget *parent)
 {
 }
 
-ElidedLable::~ElidedLable() {}
+ElidedLable::~ElidedLable() { }
 /*!
  * \brief ElidedLable::setText 设置当前文字的内容
  * \param text
@@ -124,11 +123,8 @@ void TaskWidget::onButtonClicked()
         infoTimer.stop();
     if (btnPause)
         btnPause->setEnabled(true);
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
     isShowError.storeRelaxed(false);
-#else
-    isShowError.store(false);
-#endif
+
     AbstractJobHandler::SupportActions actions = obj->property(kBtnPropertyActionName).value<AbstractJobHandler::SupportAction>();
     showConflictButtons(actions.testFlag(AbstractJobHandler::SupportAction::kPauseAction));
     actions = chkboxNotAskAgain && chkboxNotAskAgain->isChecked() ? actions | AbstractJobHandler::SupportAction::kRememberAction : actions;
@@ -149,11 +145,7 @@ void TaskWidget::parentClose()
  */
 void TaskWidget::onShowErrors(const JobInfoPointer jobInfo)
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
     isShowError.storeRelaxed(true);
-#else
-    isShowError.store(true);
-#endif
 
     AbstractJobHandler::JobErrorType errorType = jobInfo->value(AbstractJobHandler::NotifyInfoKey::kErrorTypeKey).value<AbstractJobHandler::JobErrorType>();
     QString sourceMsg = jobInfo->value(AbstractJobHandler::NotifyInfoKey::kSourceMsgKey).toString();
@@ -161,10 +153,18 @@ void TaskWidget::onShowErrors(const JobInfoPointer jobInfo)
     AbstractJobHandler::SupportActions actions = jobInfo->value(AbstractJobHandler::NotifyInfoKey::kActionsKey).value<AbstractJobHandler::SupportActions>();
     lbSrcPath->setText(sourceMsg);
     lbDstPath->setText(targetMsg);
+
+    if (errorType == AbstractJobHandler::JobErrorType::kFileMoveToTrashNoSpace) {
+        QUrl source = jobInfo->value(AbstractJobHandler::NotifyInfoKey::kSourceUrlKey).value<QUrl>();
+        onShowPermanentlyDelete(source, actions);
+        return;
+    }
+
     if (errorType == AbstractJobHandler::JobErrorType::kFileExistsError || errorType == AbstractJobHandler::JobErrorType::kDirectoryExistsError) {
         QUrl source = jobInfo->value(AbstractJobHandler::NotifyInfoKey::kSourceUrlKey).value<QUrl>();
         QUrl target = jobInfo->value(AbstractJobHandler::NotifyInfoKey::kTargetUrlKey).value<QUrl>();
-        return onShowConflictInfo(source, target, actions);
+        onShowConflictInfo(source, target, actions);
+        return;
     }
     QString errorMsg = jobInfo->value(AbstractJobHandler::NotifyInfoKey::kErrorMsgKey).toString();
     lbErrorMsg->setText(errorMsg);
@@ -243,6 +243,44 @@ void TaskWidget::onShowConflictInfo(const QUrl source, const QUrl target, const
     if (btnPause)
         btnPause->setEnabled(false);
 }
+
+void TaskWidget::onShowPermanentlyDelete(const QUrl source, const AbstractJobHandler::SupportActions action)
+{
+    if (!widButton) {
+        widButton = createBtnWidget();
+        mainLayout->addWidget(widButton);
+    }
+
+    if (!widConfict) {
+        createDestLabels = false;
+        widConfict = createConflictWidget();
+        rVLayout->addWidget(widConfict);
+    }
+
+    lbDstPath->hide();
+    lbRmTime->hide();
+    chkboxNotAskAgain->hide();
+    adjustSize();
+
+    // show messages
+    lbSrcPath->setText(QString(tr("Cannot move \"%1\" to the Trash. Delete it immediately?")).arg(source.fileName()));
+    lbErrorMsg->setText(tr("This action cannot be undone. Please proceed with caution!"));
+    lbErrorMsg->show();
+
+    // show buttons
+    showBtnByAction(action);
+
+    // show file info
+    const FileInfoPointer &info = InfoFactory::create<FileInfo>(source);
+    showFileInfo(info, true);
+    lbSrcTitle->setText(source.fileName());
+
+    widConfict->show();
+    widButton->show();
+    showConflictButtons();
+    if (btnPause)
+        btnPause->setEnabled(false);
+}
 /*!
  * \brief TaskWidget::onHandlerTaskStateChange 处理和显示当前拷贝任务的状态变化
  * \param info 这个Varint信息map
@@ -329,7 +367,6 @@ void TaskWidget::onShowTaskProccess(const JobInfoPointer JobInfo)
 
     int preValue = progress->value();
 
-    AbstractJobHandler::StatisticState state = JobInfo->value(AbstractJobHandler::NotifyInfoKey::kStatisticStateKey).value<AbstractJobHandler::StatisticState>();
     qint64 current = JobInfo->value(AbstractJobHandler::NotifyInfoKey::kCurrentProgressKey).value<qint64>();
     qint64 total = JobInfo->value(AbstractJobHandler::NotifyInfoKey::kTotalSizeKey).value<qint64>();
 
@@ -337,13 +374,6 @@ void TaskWidget::onShowTaskProccess(const JobInfoPointer JobInfo)
 
     if (total > 0 && current > 0) {
         value = static_cast<qint64>((static_cast<qreal>(current) / total) * 100);
-        if (current * 100 % total > 0)
-            value += 1;   // +1: round up value，maybe 99% when finished
-    }
-
-    if (state == AbstractJobHandler::StatisticState::kRunningState) {
-        value = value > kVirtualValue ? kVirtualValue : value;
-        value = value > preValue ? preValue + 1 : value;
     }
 
     if (value > 100) {
@@ -374,16 +404,20 @@ void TaskWidget::onShowSpeedUpdatedInfo(const JobInfoPointer JobInfo)
 {
     if (isPauseState)
         return;
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
     if (isShowError.loadRelaxed())
-#else
-    if (isShowError.load())
-#endif
         return;
 
+    if (isHover) {
+        lbSpeed->setText("");
+        lbRmTime->setText("");
+        return;
+    }
+
     if (progress->value() >= 100) {
         lbSpeed->setText(tr("Syncing data"));
+        preHoverSpeedStr = tr("Syncing data");
         lbRmTime->setText(tr("Please wait"));
+        preHoverRmTimeStr = tr("Please wait");
         return;
     }
 
@@ -397,6 +431,7 @@ void TaskWidget::onShowSpeedUpdatedInfo(const JobInfoPointer JobInfo)
             speedStr = FileUtils::formatSize(speed) + "/s";
         else
             speedStr = speedValue.toString();
+        preHoverSpeedStr = speedStr;
         lbSpeed->setText(speedStr);
     }
 
@@ -410,6 +445,7 @@ void TaskWidget::onShowSpeedUpdatedInfo(const JobInfoPointer JobInfo)
             rmTimeStr = remindValue.toString();
         if (rmTime < 0)
             rmTimeStr = "";
+        preHoverRmTimeStr = rmTimeStr;
         lbRmTime->setText(rmTimeStr);
     }
 }
@@ -429,86 +465,15 @@ void TaskWidget::initUI()
 {
     mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
-    setFixedWidth(685);
+    setFixedWidth(700);
 
-    progress = new DWaterProgress(this);
-    progress->setFixedSize(64, 64);
-    progress->setValue(1);   // fix：使一开始就有一个进度显示
-    progress->setValue(0);
-    QHBoxLayout *normalLayout = new QHBoxLayout;
-    normalLayout->setContentsMargins(20, 10, 20, 0);
-    normalLayout->addWidget(progress, Qt::AlignLeft);
-    normalLayout->addSpacing(20);
+    baseWid = createBaseWidget();
+    mainLayout->setContentsMargins(0, 0, 00, 0);
+    mainLayout->addWidget(baseWid);
 
-    lbSrcPath = new ElidedLable;
-    lbSpeed = new QLabel;
-    lbDstPath = new ElidedLable;
-    lbRmTime = new QLabel;
-    lbSrcPath->setFixedWidth(kMsgLabelWidth);
-    lbSrcPath->setText(tr("In data statistics ..."));
-    lbDstPath->setFixedWidth(kMsgLabelWidth);
-    lbSpeed->setFixedWidth(kSpeedLabelWidth);
-    lbRmTime->setFixedWidth(kSpeedLabelWidth);
-
-    rVLayout = new QVBoxLayout;
-    QHBoxLayout *hLayout1 = new QHBoxLayout;
-    hLayout1->addSpacing(15);
-    hLayout1->addWidget(lbSrcPath, Qt::AlignLeft);
-    hLayout1->addSpacing(10);
-    hLayout1->addWidget(lbSpeed, Qt::AlignRight);
-
-    QHBoxLayout *hLayout2 = new QHBoxLayout;
-    hLayout2->addSpacing(15);
-    hLayout2->addWidget(lbDstPath, Qt::AlignLeft);
-    hLayout2->addSpacing(10);
-    hLayout2->addWidget(lbRmTime, Qt::AlignRight);
-
-    lbErrorMsg = new ElidedLable;
-    lbErrorMsg->setStyleSheet("color:red;");
-    lbErrorMsg->setFixedWidth(kMsgLabelWidth + kSpeedLabelWidth);
-    QHBoxLayout *hLayout3 = new QHBoxLayout;
-    hLayout3->addSpacing(15);
-    hLayout3->addWidget(lbErrorMsg, Qt::AlignLeft);
-
-    rVLayout->addLayout(hLayout1);
-    rVLayout->addLayout(hLayout2);
-    rVLayout->addLayout(hLayout3);
-
-    normalLayout->addLayout(rVLayout);
-
-    btnStop = new DIconButton(this);
-    btnStop->setObjectName("TaskWidgetStopButton");
-    QVariant variantStop;
-    variantStop.setValue<AbstractJobHandler::SupportAction>(AbstractJobHandler::SupportAction::kStopAction);
-    btnStop->setProperty(kBtnPropertyActionName, variantStop);
-    btnStop->setIcon(QIcon::fromTheme("dfm_task_stop"));
-    btnStop->setFixedSize(24, 24);
-    btnStop->setIconSize({ 24, 24 });
-    btnStop->setFlat(true);
-    btnStop->setAttribute(Qt::WA_NoMousePropagation);
-
-    btnPause = new DIconButton(this);
-    btnPause->setObjectName("TaskWidgetPauseButton");
-    QVariant variantPause;
-    variantPause.setValue<AbstractJobHandler::SupportAction>(AbstractJobHandler::SupportAction::kPauseAction);
-    btnPause->setProperty(kBtnPropertyActionName, variantPause);
-    btnPause->setIcon(QIcon::fromTheme("dfm_task_pause"));
-    btnPause->setIconSize({ 24, 24 });
-    btnPause->setFixedSize(24, 24);
-    btnPause->setFlat(true);
-
-    normalLayout->addWidget(btnPause, Qt::AlignRight);
-    normalLayout->addSpacing(10);
-    normalLayout->addWidget(btnStop, Qt::AlignRight);
-
-    mainLayout->addLayout(normalLayout);
     mainLayout->setSpacing(0);
     mainLayout->setSizeConstraint(QLayout::SetMinAndMaxSize);
 
-    lbErrorMsg->setVisible(false);
-    btnPause->setVisible(false);
-    btnStop->setVisible(false);
-
     initConnection();
 }
 /*!
@@ -541,7 +506,7 @@ QWidget *TaskWidget::createConflictWidget()
     lbSrcModTime->setPalette(labelPalette);
 
     lbSrcFileSize = new ElidedLable();
-    lbSrcFileSize->setFixedWidth(kSpeedLabelWidth);
+    lbSrcFileSize->setFixedWidth(kFileSizeWidth);
     lbSrcFileSize->setPalette(labelPalette);
 
     lbDstIcon = new QLabel();
@@ -553,7 +518,7 @@ QWidget *TaskWidget::createConflictWidget()
     lbDstModTime->setPalette(labelPalette);
 
     lbDstFileSize = new ElidedLable();
-    lbDstFileSize->setFixedWidth(kSpeedLabelWidth);
+    lbDstFileSize->setFixedWidth(kFileSizeWidth);
     lbDstFileSize->setPalette(labelPalette);
 
     QGridLayout *conflictMainLayout = new QGridLayout();
@@ -563,20 +528,22 @@ QWidget *TaskWidget::createConflictWidget()
     conflictMainLayout->addWidget(lbSrcModTime, 1, 1, Qt::AlignVCenter);
     conflictMainLayout->addWidget(lbSrcFileSize, 1, 2, Qt::AlignVCenter);
 
-    conflictMainLayout->addWidget(lbDstIcon, 2, 0, 2, 1, Qt::AlignVCenter);
-    conflictMainLayout->addWidget(lbDstTitle, 2, 1, 1, 2, Qt::AlignVCenter);
-    conflictMainLayout->addWidget(lbDstModTime, 3, 1, Qt::AlignVCenter);
-    conflictMainLayout->addWidget(lbDstFileSize, 3, 2, Qt::AlignVCenter);
+    if (createDestLabels) {
+        conflictMainLayout->addWidget(lbDstIcon, 2, 0, 2, 1, Qt::AlignVCenter);
+        conflictMainLayout->addWidget(lbDstTitle, 2, 1, 1, 2, Qt::AlignVCenter);
+        conflictMainLayout->addWidget(lbDstModTime, 3, 1, Qt::AlignVCenter);
+        conflictMainLayout->addWidget(lbDstFileSize, 3, 2, Qt::AlignVCenter);
+    }
 
     conflictMainLayout->setHorizontalSpacing(4);
     conflictMainLayout->setVerticalSpacing(4);
     conflictMainLayout->setContentsMargins(0, 0, 0, 0);
-    conflictMainLayout->setColumnMinimumWidth(1, kMsgLabelWidth - 100);
+    conflictMainLayout->setColumnMinimumWidth(1, kMsgLabelWidth - kSpeedLabelWidth);
 
     QHBoxLayout *hLayout = new QHBoxLayout;
     hLayout->addLayout(conflictMainLayout);
     conflictWidget->setLayout(hLayout);
-    conflictWidget->setMaximumWidth(565);
+    conflictWidget->setMaximumWidth(580);
 
     return conflictWidget;
 }
@@ -594,33 +561,41 @@ QWidget *TaskWidget::createBtnWidget()
 
     QVariant variantCoexit;
     variantCoexit.setValue<AbstractJobHandler::SupportAction>(AbstractJobHandler::SupportAction::kCoexistAction);
-    btnCoexist = new QPushButton(TaskWidget::tr("Keep both", "button"));
+    btnCoexist = new DPushButton(TaskWidget::tr("Keep both", "button"));
     btnCoexist->setProperty(kBtnPropertyActionName, variantCoexit);
 
-    btnSkip = new QPushButton(TaskWidget::tr("Skip", "button"));
+    btnSkip = new DPushButton(TaskWidget::tr("Skip", "button"));
     QVariant variantSkip;
     variantSkip.setValue<AbstractJobHandler::SupportAction>(AbstractJobHandler::SupportAction::kSkipAction);
     btnSkip->setProperty(kBtnPropertyActionName, variantSkip);
 
-    btnReplace = new QPushButton(TaskWidget::tr("Replace", "button"));
+    btnReplace = new DPushButton(TaskWidget::tr("Replace", "button"));
     QVariant variantReplace;
     variantReplace.setValue<AbstractJobHandler::SupportAction>(AbstractJobHandler::SupportAction::kReplaceAction);
     btnReplace->setProperty(kBtnPropertyActionName, variantReplace);
 
+    btnDelete = new DWarningButton();
+    btnDelete->setText(TaskWidget::tr("Permanently delete", "button"));
+    QVariant varianDelete;
+    varianDelete.setValue<AbstractJobHandler::SupportAction>(AbstractJobHandler::SupportAction::kPermanentlyDelete);
+    btnDelete->setProperty(kBtnPropertyActionName, varianDelete);
+
     btnSkip->setFocusPolicy(Qt::NoFocus);
     btnReplace->setFocusPolicy(Qt::NoFocus);
 
     btnCoexist->setCheckable(true);
     btnCoexist->setChecked(true);
 
-    btnSkip->setFixedWidth(80);
-    btnReplace->setFixedWidth(80);
-    btnCoexist->setFixedWidth(160);
+    btnSkip->setFixedWidth(78);
+    btnReplace->setFixedWidth(78);
+    btnCoexist->setFixedWidth(158);
+    btnDelete->setFixedWidth(158);
 
     buttonLayout->addStretch(1);
     buttonLayout->addWidget(btnSkip);
     buttonLayout->addWidget(btnReplace);
     buttonLayout->addWidget(btnCoexist);
+    buttonLayout->addWidget(btnDelete);
 
     buttonLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -628,7 +603,7 @@ QWidget *TaskWidget::createBtnWidget()
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     chkboxNotAskAgain = new QCheckBox(TaskWidget::tr("Do not ask again"));
-    layout->addSpacing(120);
+    layout->addSpacing(100);
     layout->addWidget(chkboxNotAskAgain);
 
     QVBoxLayout *btnMainLayout = new QVBoxLayout;
@@ -642,9 +617,107 @@ QWidget *TaskWidget::createBtnWidget()
     connect(btnSkip, &QPushButton::clicked, this, &TaskWidget::onButtonClicked);
     connect(btnReplace, &QPushButton::clicked, this, &TaskWidget::onButtonClicked);
     connect(btnCoexist, &QPushButton::clicked, this, &TaskWidget::onButtonClicked);
+    connect(btnDelete, &QPushButton::clicked, this, &TaskWidget::onButtonClicked);
 
     return buttonWidget;
 }
+
+QWidget *TaskWidget::createBaseWidget()
+{
+    QWidget *baseWidget = new QWidget;
+
+    // 进度动画
+    progress = new DWaterProgress(this);
+    progress->setFixedSize(64, 64);
+    progress->setValue(1);   // fix：使一开始就有一个进度显示
+    progress->setValue(0);
+    QHBoxLayout *normalLayout = new QHBoxLayout;
+    normalLayout->setContentsMargins(20, 10, 20, 10);
+    normalLayout->addWidget(progress, Qt::AlignLeft);
+    normalLayout->addSpacing(2);
+
+    lbSrcPath = new ElidedLable;
+    lbSpeed = new QLabel;
+    lbDstPath = new ElidedLable;
+    lbRmTime = new QLabel;
+    lbSrcPath->setFixedWidth(kMsgLabelWidth);
+    lbSrcPath->setText(tr("In data statistics ..."));
+    lbDstPath->setFixedWidth(kMsgLabelWidth);
+    lbSpeed->setFixedWidth(kSpeedLabelWidth);
+    lbRmTime->setFixedWidth(kSpeedLabelWidth);
+
+    rVLayout = new QVBoxLayout;
+
+    QHBoxLayout *hLayout1 = new QHBoxLayout;
+    hLayout1->addSpacing(12);
+    hLayout1->addWidget(lbSrcPath, Qt::AlignLeft);
+    hLayout1->addSpacing(10);
+    hLayout1->addWidget(lbSpeed, Qt::AlignRight);
+
+    QHBoxLayout *hLayout2 = new QHBoxLayout;
+    hLayout2->addSpacing(12);
+    hLayout2->addWidget(lbDstPath, Qt::AlignLeft);
+    hLayout2->addSpacing(10);
+    hLayout2->addWidget(lbRmTime, Qt::AlignRight);
+
+    QVBoxLayout *vLayout1 = new QVBoxLayout;
+    vLayout1->addLayout(hLayout1, Qt::AlignTop);
+    vLayout1->addLayout(hLayout2, Qt::AlignBottom);
+
+    lbErrorMsg = new ElidedLable;
+    lbErrorMsg->setStyleSheet("color:red;");
+    lbErrorMsg->setFixedWidth(kMsgLabelWidth + kSpeedLabelWidth + 20);
+    QHBoxLayout *hLayout3 = new QHBoxLayout;
+    hLayout3->addSpacing(12);
+    hLayout3->addWidget(lbErrorMsg, Qt::AlignLeft);
+
+    btnStop = new DIconButton(this);
+    btnStop->setObjectName("TaskWidgetStopButton");
+    QVariant variantStop;
+    variantStop.setValue<AbstractJobHandler::SupportAction>(AbstractJobHandler::SupportAction::kStopAction);
+    btnStop->setProperty(kBtnPropertyActionName, variantStop);
+    btnStop->setIcon(QIcon::fromTheme("dfm_task_stop"));
+    btnStop->setFixedSize(24, 24);
+    btnStop->setIconSize({ 24, 24 });
+    btnStop->setFlat(true);
+    btnStop->setAttribute(Qt::WA_NoMousePropagation);
+
+    btnPause = new DIconButton(this);
+    btnPause->setObjectName("TaskWidgetPauseButton");
+    QVariant variantPause;
+    variantPause.setValue<AbstractJobHandler::SupportAction>(AbstractJobHandler::SupportAction::kPauseAction);
+    btnPause->setProperty(kBtnPropertyActionName, variantPause);
+    btnPause->setIcon(QIcon::fromTheme("dfm_task_pause"));
+    btnPause->setIconSize({ 24, 24 });
+    btnPause->setFixedSize(24, 24);
+    btnPause->setFlat(true);
+
+    hLayout4 = new QHBoxLayout;
+
+    hLayout4->addWidget(btnPause, Qt::AlignLeft);
+    hLayout4->addSpacing(15);
+    hLayout4->addWidget(btnStop, Qt::AlignRight);
+    hLayout4->addSpacing(35);   // 前面只有 24 + 15 + 24
+
+    hLayout5 = new QHBoxLayout;
+    hLayout5->addLayout(vLayout1);
+
+    rVLayout->addLayout(hLayout5);
+    rVLayout->addLayout(hLayout3);
+
+    normalLayout->addLayout(rVLayout);
+
+    lbErrorMsg->setVisible(false);
+    btnPause->setVisible(false);
+    btnStop->setVisible(false);
+
+    baseWidget->setLayout(normalLayout);
+
+    baseWidget->setFixedWidth(700);
+
+    return baseWidget;
+}
+
 /*!
  * \brief TaskWidget::showBtnByAction 根据不同的操作显示不同的按钮
  * \param action
@@ -653,6 +726,8 @@ void TaskWidget::showBtnByAction(const AbstractJobHandler::SupportActions &actio
 {
     btnSkip->setHidden(!actions.testFlag(AbstractJobHandler::SupportAction::kSkipAction));
     btnCoexist->setHidden(!actions.testFlag(AbstractJobHandler::SupportAction::kCoexistAction));
+    btnDelete->setHidden(!actions.testFlag(AbstractJobHandler::SupportAction::kPermanentlyDelete));
+
     QString btnTxt;
     QVariant variantReplace;
     if (actions.testFlag(AbstractJobHandler::SupportAction::kRetryAction)) {
@@ -690,23 +765,37 @@ void TaskWidget::showConflictButtons(bool showBtns, bool showConflict)
     }
 
     adjustSize();
-    emit heightChanged(this->height());
+    QTimer::singleShot(0, this, [this] {
+        emit heightChanged(this->height());
+    });
 }
 
 void TaskWidget::onMouseHover(const bool hover)
 {
-    if (isBtnHidden) {
+    if (widConfict && widConfict->isVisible()) {
         btnPause->setVisible(false);
         btnStop->setVisible(false);
+        return;
+    }
+
+    if (isBtnHidden) {
+        isHover = hover;
+        btnPause->setVisible(false);
+        btnStop->setVisible(false);
+        lbSpeed->setVisible(true);
+        lbRmTime->setVisible(true);
     } else {
+        if (hover) {
+            hLayout5->addLayout(hLayout4);
+        } else {
+            hLayout5->removeItem(hLayout4);
+        }
+        lbSpeed->setHidden(hover);
+        lbRmTime->setHidden(hover);
         btnPause->setVisible(hover);
         btnStop->setVisible(hover);
     }
 
-    lbSpeed->setHidden(hover);
-    lbRmTime->setHidden(hover);
-    lbSrcPath->setFixedWidth(hover ? kMsgLabelHoverWidth : kMsgLabelWidth);
-    lbDstPath->setFixedWidth(hover ? kMsgLabelHoverWidth : kMsgLabelWidth);
     adjustSize();
 }
 
@@ -809,11 +898,7 @@ bool TaskWidget::showFileInfo(const FileInfoPointer info, const bool isOrg)
     return needRetry;
 }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 void TaskWidget::enterEvent(QEnterEvent *event)
-#else
-void TaskWidget::enterEvent(QEvent *event)
-#endif
 {
     onMouseHover(true);
 
@@ -835,14 +920,14 @@ void TaskWidget::paintEvent(QPaintEvent *event)
     if (opt.state & QStyle::State_MouseOver) {
         int radius = 8;
         QRectF bgRect;
-        bgRect.setSize(size());
+        bgRect.setSize(QSize(684, size().height()));
         QPainterPath path;
         path.addRoundedRect(bgRect, radius, radius);
         QColor bgColor;
         if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
-            bgColor = QColor(0, 0, 0, 13);   //rgba(0,0,0,13); border-radius: 8px
+            bgColor = QColor(0, 0, 0, 13);   // rgba(0,0,0,13); border-radius: 8px
         } else {
-            bgColor = QColor(255, 255, 255, 13);   //rgba(255,255,255,13); border-radius: 8px
+            bgColor = QColor(255, 255, 255, 13);   // rgba(255,255,255,13); border-radius: 8px
         }
         painter.save();
         painter.setRenderHint(QPainter::Antialiasing, true);
