@@ -78,6 +78,23 @@ int DialogManager::showMessageDialog(DialogManager::MessageType messageLevel, co
     return code;
 }
 
+int DialogManager::showMessageDialog(MessageType messageLevel, const QString &title, const QString &message, const QStringList &btnTxtList)
+{
+    DDialog d(title, message, qApp->activeWindow());
+    d.moveToCenter();
+    d.addButtons(btnTxtList);
+    d.setDefaultButton(btnTxtList.size() - 1);
+    if (messageLevel == kMsgWarn) {
+        d.setIcon(warningIcon);
+    } else if (messageLevel == kMsgErr) {
+        d.setIcon(errorIcon);
+    } else {
+        d.setIcon(infoIcon);
+    }
+    int code = d.exec();
+    return code;
+}
+
 void DialogManager::showErrorDialogWhenOperateDeviceFailed(OperateType type, DFMMOUNT::OperationErrorInfo err)
 {
     static const QString kOpFailed = tr("Operating failed");
@@ -150,11 +167,8 @@ void DialogManager::showErrorDialogWhenOperateDeviceFailed(OperateType type, DFM
             errMsg = tr("Authentication failed");
         else if (static_cast<int>(err.code) == ENOENT)
             errMsg = tr("No such file or directory");
-        else if (err.code >= DeviceError::kGIOError
-                 && err.code <= DeviceError::kGIOErrorMessageTooLarge)
-            errMsg = err.message;
         else
-            errMsg = tr("Error occured while mounting device");
+            errMsg = tr("Authentication failed");
 
         if (err.message.contains("Operation not permitted.")) {   // TASK(222725)
             errMsg = tr("The device has been blocked and you do not have permission to access it. "
