@@ -29,6 +29,9 @@
 #    include <KCodecs>
 #    include <KEncodingProber>
 #endif
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#    include <QColorSpace>
+#endif
 
 #include <dfm-io/dfmio_utils.h>
 #include <dfm-io/dfile.h>
@@ -159,7 +162,7 @@ int FileUtils::supportedMaxLength(const QString &fileSystem)
         { "reiserfs", 15 },   // man 8 mkreiserfs said its max length is 16, but after tested, only 15 chars are accepted.
         { "xfs", 12 }   // https://github.com/edward6/reiser4progs/blob/master/include/reiser4/types.h fs_hint_t
     };
-    return datas.value(fileSystem.toLower(), 11);
+    return datas.value(fileSystem.toLower(), 40);
 }
 
 QString FileUtils::preprocessingFileName(QString name)
@@ -256,7 +259,9 @@ bool FileUtils::isDesktopFileInfo(const FileInfoPointer &info)
 {
     Q_ASSERT(info);
     const QString &suffix = info->nameOf(NameInfoType::kSuffix);
-    if (suffix == DFMBASE_NAMESPACE::Global::Scheme::kDesktop) {
+    if (suffix == DFMBASE_NAMESPACE::Global::Scheme::kDesktop
+        || info->urlOf(UrlInfoType::kParentUrl).path() == StandardPaths::location(StandardPaths::StandardLocation::kDesktopPath)
+        || info->extendAttributes(ExtInfoType::kFileLocalDevice).toBool()) {
         const QUrl &url = info->urlOf(UrlInfoType::kUrl);
         QMimeType type = info->fileMimeType();
         if (!type.isValid())
@@ -684,66 +689,6 @@ QString FileUtils::cutFileName(const QString &name, int maxLength, bool useCharC
     return tmpName;
 }
 
-QString FileUtils::nonExistSymlinkFileName(const QUrl &fileUrl, const QUrl &parentUrl)
-{
-    const FileInfoPointer &info = InfoFactory::create<FileInfo>(fileUrl);
-
-    if (info && DFMIO::DFile(fileUrl).exists()) {
-        QString baseName = info->displayOf(DisPlayInfoType::kFileDisplayName) == info->nameOf(NameInfoType::kFileName)
-                ? info->nameOf(NameInfoType::kBaseName)
-                : info->displayOf(DisPlayInfoType::kFileDisplayName);
-        QString shortcut = QObject::tr("Shortcut");
-        QString linkBaseName;
-
-        int number = 0;
-
-        forever {
-            if (info->isAttributes(OptInfoType::kIsFile)) {
-                if (info->nameOf(NameInfoType::kSuffix).isEmpty()) {
-                    if (number == 0) {
-                        linkBaseName = QString("%1 %2").arg(baseName, shortcut);
-                    } else {
-                        linkBaseName = QString("%1 %2%3").arg(baseName, shortcut, QString::number(number));
-                    }
-                } else {
-                    if (number == 0) {
-                        linkBaseName = QString("%1 %2.%3").arg(baseName, shortcut, info->nameOf(NameInfoType::kSuffix));
-                    } else {
-                        linkBaseName = QString("%1 %2%3.%4").arg(baseName, shortcut, QString::number(number), info->nameOf(NameInfoType::kSuffix));
-                    }
-                }
-            } else if (info->isAttributes(OptInfoType::kIsDir)) {
-                if (number == 0) {
-                    linkBaseName = QString("%1 %2").arg(baseName, shortcut);
-                } else {
-                    linkBaseName = QString("%1 %2%3").arg(baseName, shortcut, QString::number(number));
-                }
-            } else if (info->isAttributes(OptInfoType::kIsSymLink)) {
-                return QString();
-            }
-
-            if (parentUrl.isEmpty()) {
-                return linkBaseName;
-            }
-
-            QDir parentDir = QDir(parentUrl.path());
-            if (parentDir.exists(linkBaseName)) {
-                ++number;
-            } else {
-                // 链接文件失效后exists会返回false，通过lstat再次判断链接文件本身是否存在
-                auto strLinkPath = parentDir.filePath(linkBaseName).toStdString();
-                struct stat st;
-                if ((lstat(strLinkPath.c_str(), &st) == 0) && S_ISLNK(st.st_mode))
-                    ++number;
-                else
-                    return linkBaseName;
-            }
-        }
-    }
-
-    return QString();
-}
-
 QString FileUtils::toUnicode(const QByteArray &data, const QString &fileName)
 {
     if (data.isEmpty())
@@ -1029,6 +974,87 @@ QString FileUtils::resolveSymlink(const QUrl &url)
     return target;
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+/**
+   @brief 转换图片颜色空间到sRGB，解决CMYK等颜色空间图片显示颜色不正确的问题
+   @param image 原始图片
+   @return 转换后的图片，如果不需要转换或转换失败则返回原图
+   @note 此功能仅在Qt6中可用
+ */
+QImage FileUtils::convertToSRgbColorSpace(const QImage &image)
+{
+    if (image.isNull())
+        return image;
+
+    QColorSpace srgbColorSpace = QColorSpace::SRgb;
+    bool needsConversion = false;
+    if (image.colorSpace().isValid()) {
+        qCDebug(logDFMBase) << "Image has color space:" << image.colorSpace().description();
+
+        if (image.colorSpace() != srgbColorSpace) {
+            needsConversion = true;
+            qCDebug(logDFMBase) << "Converting color space from" << image.colorSpace().description()
+                                << "to sRGB";
+        }
+    } else {
+        qCDebug(logDFMBase) << "Image has no valid color space, checking format for potential CMYK";
+        if (image.format() == QImage::Format_CMYK8888) {
+            needsConversion = true;
+            qCDebug(logDFMBase) << "CMYK format detected, attempting conversion";
+        }
+    }
+
+    if (!needsConversion) {
+        qCDebug(logDFMBase) << "No color space conversion needed";
+        return image;
+    }
+
+    QImage convertedImage = QImage();
+    try {
+        convertedImage = image.convertedToColorSpace(srgbColorSpace);
+        if (!convertedImage.isNull()) {
+            qCDebug(logDFMBase) << "Color space conversion method 1 (convertedToColorSpace) succeeded";
+        } else {
+            qCDebug(logDFMBase) << "Color space conversion method 1 failed";
+        }
+    } catch (...) {
+        qCDebug(logDFMBase) << "Color space conversion method 1 threw exception";
+    }
+
+    if (convertedImage.isNull()) {
+        qCDebug(logDFMBase) << "Trying color space conversion method 2: manual color space setting";
+
+        convertedImage = image.copy();
+        convertedImage.setColorSpace(srgbColorSpace);
+
+        if (convertedImage.format() != QImage::Format_RGB888 && convertedImage.format() != QImage::Format_ARGB32 && convertedImage.format() != QImage::Format_ARGB32_Premultiplied) {
+            convertedImage = convertedImage.convertToFormat(QImage::Format_RGB888);
+        }
+
+        if (!convertedImage.isNull()) {
+            qCDebug(logDFMBase) << "Color space conversion method 2 succeeded";
+        }
+    }
+
+    if (convertedImage.isNull()) {
+        qCDebug(logDFMBase) << "Trying color space conversion method 3: basic format conversion";
+        convertedImage = image.convertToFormat(QImage::Format_RGB888);
+        convertedImage.setColorSpace(srgbColorSpace);
+
+        if (!convertedImage.isNull()) {
+            qCDebug(logDFMBase) << "Color space conversion method 3 succeeded";
+        }
+    }
+
+    if (convertedImage.isNull()) {
+        qCWarning(logDFMBase) << "All color space conversion methods failed, returning original image";
+        return image;
+    }
+
+    return convertedImage;
+}
+#endif
+
 QString FileUtils::encryptString(const QString &str)
 {
     QByteArray byteArray = str.toUtf8();
@@ -1104,8 +1130,6 @@ bool FileUtils::setBackGround(const QString &pictureFilePath)
     return true;
 }
 
-
-
 QString FileUtils::bindPathTransform(const QString &path, bool toDevice)
 {
     return DeviceUtils::bindPathTransform(path, toDevice);
@@ -1211,7 +1235,7 @@ QString FileUtils::normalPathToTrash(const QString &normal)
 bool FileUtils::supportLongName(const QUrl &url)
 {
     const static QList<QString> datas {
-        "vfat", "exfat", "ntfs", "fuseblk", "fuse.dlnfs"
+        "vfat", "exfat", "ntfs", "ntfs3", "fuseblk", "fuse.dlnfs", "udf"
     };
 
     const QString &fileSystem = dfmio::DFMUtils::fsTypeFromUrl(url);
@@ -1330,66 +1354,6 @@ float codecConfidenceForData(const QTextCodec *codec, const QByteArray &data, co
 }
 #endif
 
-Match::Match(const QString &group)
-{
-    for (const QString &key : Application::instance()->genericObtuselySetting()->keys(group)) {
-        const QString &value = Application::instance()->genericObtuselySetting()->value(group, key).toString();
-
-        int last_dir_split = value.lastIndexOf(QDir::separator());
-
-        if (last_dir_split >= 0) {
-            QString path = value.left(last_dir_split);
-
-            if (path.startsWith("~/")) {
-                path.replace(0, 1, QDir::homePath());
-            }
-
-            patternList << qMakePair(path, value.mid(last_dir_split + 1));
-        } else {
-            patternList << qMakePair(QString(), value);
-        }
-    }
-}
-
-bool Match::match(const QString &path, const QString &name)
-{
-    // 这里可能会析构 先复制一份再循环
-    const QList<QPair<QString, QString>> patternListNew = patternList;
-    for (auto pattern : patternListNew) {
-        QRegularExpression re(QString(), QRegularExpression::MultilineOption);
-
-        if (!pattern.first.isEmpty()) {
-            re.setPattern(pattern.first);
-
-            if (!re.isValid()) {
-                qCWarning(logDFMBase) << re.errorString();
-                continue;
-            }
-
-            if (!re.match(path).hasMatch()) {
-                continue;
-            }
-        }
-
-        if (pattern.second.isEmpty()) {
-            return true;
-        }
-
-        re.setPattern(pattern.second);
-
-        if (!re.isValid()) {
-            qCWarning(logDFMBase) << re.errorString();
-            continue;
-        }
-
-        if (re.match(name).hasMatch()) {
-            return true;
-        }
-    }
-
-    return false;
-}
-
 QString FileUtils::findIconFromXdg(const QString &iconName)
 {
     // NOTE: qtxdg-dev-tools only Qt5 supported now!
