@@ -5,11 +5,25 @@
 #include <dfm-framework/lifecycle/lifecycle.h>
 #include <dfm-framework/lifecycle/pluginmanager.h>
 #include <dfm-framework/lifecycle/pluginmetaobject.h>
+#include <mutex>
 
 DPF_BEGIN_NAMESPACE
 namespace LifeCycle {
 
-Q_GLOBAL_STATIC(PluginManager, pluginManager);
+/*!
+ * \brief getPluginManager Get the global plugin manager instance
+ * \details Uses Leaky Singleton pattern to avoid static destruction order issues.
+ * The instance is created once and never destroyed, which is safe for system-level
+ * plugin managers that need to exist throughout the entire program lifecycle.
+ * \return Pointer to the global PluginManager instance
+ */
+static PluginManager* getPluginManager()
+{
+    // C++11 guarantees thread-safe initialization of function static variables
+    // The instance is created on first call and never destroyed
+    static PluginManager* instance = new PluginManager();
+    return instance;
+}
 
 /*!
  * \brief LifeCycle::initialize
@@ -21,28 +35,42 @@ Q_GLOBAL_STATIC(PluginManager, pluginManager);
  */
 void initialize(const QStringList &IIDs, const QStringList &paths)
 {
+    qCInfo(logDPF) << "LifeCycle: initializing with" << IIDs.size() << "IIDs and" << paths.size() << "paths";
+    qCDebug(logDPF) << "LifeCycle: IIDs:" << IIDs;
+    qCDebug(logDPF) << "LifeCycle: paths:" << paths;
+    
     for (const QString &id : IIDs)
-        pluginManager->addPluginIID(id);
-    pluginManager->setPluginPaths(paths);
+        getPluginManager()->addPluginIID(id);
+    getPluginManager()->setPluginPaths(paths);
+    
+    qCInfo(logDPF) << "LifeCycle: initialization completed";
 }
 
 void initialize(const QStringList &IIDs, const QStringList &paths, const QStringList &blackNames)
 {
+    qCInfo(logDPF) << "LifeCycle: initializing with blacklist," << blackNames.size() << "blacklisted plugins";
+    qCDebug(logDPF) << "LifeCycle: blacklisted plugins:" << blackNames;
+    
     for (const QString &name : blackNames)
-        pluginManager->addBlackPluginName(name);
+        getPluginManager()->addBlackPluginName(name);
     initialize(IIDs, paths);
 }
 
 void initialize(const QStringList &IIDs, const QStringList &paths, const QStringList &blackNames, const QStringList &lazyNames)
 {
+    qCInfo(logDPF) << "LifeCycle: initializing with lazy loading," << lazyNames.size() << "lazy plugins";
+    qCDebug(logDPF) << "LifeCycle: lazy plugins:" << lazyNames;
+    
     for (const QString &name : lazyNames)
-        pluginManager->addLazyLoadPluginName(name);
+        getPluginManager()->addLazyLoadPluginName(name);
     initialize(IIDs, paths, blackNames);
 }
 
 void registerQtVersionInsensitivePlugins(const QStringList &names)
 {
-    pluginManager->setQtVersionInsensitivePluginNames(names);
+    qCInfo(logDPF) << "LifeCycle: registering" << names.size() << "Qt version insensitive plugins";
+    qCDebug(logDPF) << "LifeCycle: Qt version insensitive plugins:" << names;
+    getPluginManager()->setQtVersionInsensitivePluginNames(names);
 }
 
 /*!
@@ -51,7 +79,7 @@ void registerQtVersionInsensitivePlugins(const QStringList &names)
  */
 QStringList pluginIIDs()
 {
-    return pluginManager->pluginIIDs();
+    return getPluginManager()->pluginIIDs();
 }
 
 /*!
@@ -60,28 +88,28 @@ QStringList pluginIIDs()
  */
 QStringList pluginPaths()
 {
-    return pluginManager->pluginPaths();
+    return getPluginManager()->pluginPaths();
 }
 
 QStringList blackList()
 {
-    return pluginManager->blackList();
+    return getPluginManager()->blackList();
 }
 
 QStringList lazyLoadList()
 {
-    return pluginManager->lazyLoadList();
+    return getPluginManager()->lazyLoadList();
 }
 
 PluginMetaObjectPointer pluginMetaObj(const QString &pluginName,
                                       const QString version)
 {
-    return pluginManager->pluginMetaObj(pluginName, version);
+    return getPluginManager()->pluginMetaObj(pluginName, version);
 }
 
 QList<PluginMetaObjectPointer> pluginMetaObjs(const std::function<bool(PluginMetaObjectPointer)> &cond)
 {
-    const auto &queue { pluginManager->readQueue() };
+    const auto &queue { getPluginManager()->readQueue() };
     if (!cond)
         return queue;
 
@@ -95,7 +123,7 @@ QList<PluginMetaObjectPointer> pluginMetaObjs(const std::function<bool(PluginMet
 
 QList<PluginMetaObjectPointer> pluginSortedMetaObjs(const std::function<bool(PluginMetaObjectPointer)> &cond)
 {
-    const auto &queue { pluginManager->loadQueue() };
+    const auto &queue { getPluginManager()->loadQueue() };
     if (!cond)
         return queue;
 
@@ -120,7 +148,10 @@ QList<PluginMetaObjectPointer> pluginSortedMetaObjs(const std::function<bool(Plu
  */
 bool readPlugins()
 {
-    return pluginManager->readPlugins();
+    qCInfo(logDPF) << "LifeCycle: starting to read plugins";
+    bool result = getPluginManager()->readPlugins();
+    qCInfo(logDPF) << "LifeCycle: read plugins completed, success:" << result;
+    return result;
 }
 
 /*!
@@ -141,10 +172,16 @@ bool readPlugins()
  */
 bool loadPlugins()
 {
-    bool result { pluginManager->loadPlugins() };
+    qCInfo(logDPF) << "LifeCycle: starting plugin loading sequence";
+    
+    bool result { getPluginManager()->loadPlugins() };
+    qCInfo(logDPF) << "LifeCycle: plugin loading phase completed, success:" << result;
 
-    pluginManager->initPlugins();
-    pluginManager->startPlugins();
+    getPluginManager()->initPlugins();
+    qCInfo(logDPF) << "LifeCycle: plugin initialization phase completed";
+    
+    getPluginManager()->startPlugins();
+    qCInfo(logDPF) << "LifeCycle: plugin startup phase completed";
 
     return result;
 }
@@ -161,44 +198,78 @@ bool loadPlugins()
  */
 void shutdownPlugins()
 {
-    pluginManager->stopPlugins();
+    static std::once_flag shutdownOnce;
+    
+    std::call_once(shutdownOnce, []() {
+        qCInfo(logDPF) << "LifeCycle: starting plugin shutdown";
+        // Now this call is always safe because the instance is never destroyed
+        getPluginManager()->stopPlugins();
+        qCInfo(logDPF) << "LifeCycle: plugin shutdown completed";
+    });
 }
 
 bool loadPlugin(PluginMetaObjectPointer &pointer)
 {
-    if (!pluginManager->loadPlugin(pointer))
+    if (!pointer) {
+        qCWarning(logDPF) << "LifeCycle: attempted to load null plugin pointer";
         return false;
-    if (!pluginManager->initPlugin(pointer))
+    }
+    
+    qCInfo(logDPF) << "LifeCycle: loading single plugin:" << pointer->name();
+    
+    if (!getPluginManager()->loadPlugin(pointer)) {
+        qCWarning(logDPF) << "LifeCycle: failed to load plugin:" << pointer->name();
         return false;
-    if (!pluginManager->startPlugin(pointer))
+    }
+    if (!getPluginManager()->initPlugin(pointer)) {
+        qCWarning(logDPF) << "LifeCycle: failed to initialize plugin:" << pointer->name();
         return false;
+    }
+    if (!getPluginManager()->startPlugin(pointer)) {
+        qCWarning(logDPF) << "LifeCycle: failed to start plugin:" << pointer->name();
+        return false;
+    }
 
+    qCInfo(logDPF) << "LifeCycle: successfully loaded plugin:" << pointer->name();
     return true;
 }
 
 void shutdownPlugin(PluginMetaObjectPointer &pointer)
 {
-    pluginManager->stopPlugin(pointer);
+    if (!pointer) {
+        qCWarning(logDPF) << "LifeCycle: attempted to shutdown null plugin pointer";
+        return;
+    }
+    
+    qCInfo(logDPF) << "LifeCycle: shutting down plugin:" << pointer->name();
+    getPluginManager()->stopPlugin(pointer);
+    qCInfo(logDPF) << "LifeCycle: plugin shutdown completed:" << pointer->name();
 }
 
 bool isAllPluginsInitialized()
 {
-    return pluginManager->isAllPluginsInitialized();
+    bool result = getPluginManager()->isAllPluginsInitialized();
+    qCDebug(logDPF) << "LifeCycle: all plugins initialized:" << result;
+    return result;
 }
 
 bool isAllPluginsStarted()
 {
-    return pluginManager->isAllPluginsStarted();
+    bool result = getPluginManager()->isAllPluginsStarted();
+    qCDebug(logDPF) << "LifeCycle: all plugins started:" << result;
+    return result;
 }
 
 void setLazyloadFilter(std::function<bool(const QString &)> filter)
 {
-    pluginManager->setLazyLoadFilter(filter);
+    qCInfo(logDPF) << "LifeCycle: setting lazy load filter";
+    getPluginManager()->setLazyLoadFilter(filter);
 }
 
 void setBlackListFilter(std::function<bool(const QString &)> filter)
 {
-    pluginManager->setBlackListFilter(filter);
+    qCInfo(logDPF) << "LifeCycle: setting blacklist filter";
+    getPluginManager()->setBlackListFilter(filter);
 }
 
 }   // namespace LifeCycle
