@@ -16,7 +16,6 @@
 #include <QStorageInfo>
 #include <QQueue>
 
-
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/stat.h>
@@ -44,15 +43,14 @@ bool DoCutFilesWorker::doWork()
     determineCountProcessType();
 
     // 执行剪切
+    fmInfo() << "Start cutting files - count:" << sourceUrls.count();
     if (!cutFiles()) {
         endWork();
         return false;
     }
 
-    // sync
-    syncFilesToDevice();
-
     // 完成
+    fmInfo() << "Cut operation completed successfully";
     endWork();
 
     return true;
@@ -110,6 +108,7 @@ bool DoCutFilesWorker::cutFiles()
         if (fileInfo->attribute(DFileInfo::AttributeID::kStandardIsDir).toBool()) {
             const bool higher = FileUtils::isHigherHierarchy(url, targetUrl) || url == targetUrl;
             if (higher) {
+                fmWarning() << "Cannot move directory to itself or parent - from:" << url << "to:" << targetUrl;
                 emit requestShowTipsDialog(DFMBASE_NAMESPACE::AbstractJobHandler::ShowDialogType::kCopyMoveToSelf, {});
                 return false;
             }
@@ -133,48 +132,61 @@ bool DoCutFilesWorker::cutFiles()
 
 bool DoCutFilesWorker::doCutFile(const DFileInfoPointer &fromInfo, const DFileInfoPointer &targetPathInfo, bool *skip)
 {
-    // try rename
-    bool ok = false;
-    // 获取trashinfourl
     QUrl trashInfoUrl;
     QString fileName = fromInfo->attribute(DFileInfo::AttributeID::kStandardFileName).toString();
-    bool isTrashFile = FileUtils::isTrashFile(fromInfo->uri());
+    const bool isTrashFile = FileUtils::isTrashFile(fromInfo->uri());
     if (isTrashFile) {
         trashInfoUrl = trashInfo(fromInfo);
         fileName = fileOriginName(trashInfoUrl);
     }
-    DFileInfoPointer toInfo = doRenameFile(fromInfo, targetPathInfo, fileName, &ok, skip);
+    DFileInfoPointer toInfo = nullptr;
+    bool success = false;
 
-    auto fromSize = fromInfo->attribute(DFileInfo::AttributeID::kStandardSize).toLongLong();
-    if (ok) {
+    // 检查是否再同一个挂载点下，不再就执行copyAndDeleteFile
+    const bool isSameDevice = DFMIO::DFMUtils::mountPathFromUrl(fromInfo->uri()) == DFMIO::DFMUtils::mountPathFromUrl(targetOrgUrl);
+    if (isSameDevice) {
+        // Same device: try to rename directly. This is the fast path for moving files.
+        bool renameOk = false;
+        toInfo = trySameDeviceRename(fromInfo, targetPathInfo, fileName, &renameOk, skip);
+        success = renameOk;
+        if (!success) {
+            fmWarning() << "Same-device rename failed - from:" << fromInfo->uri();
+            // If rename fails on the same device, it's a genuine error. We should not fall back to copy-delete.
+            // Return false unless the operation was skipped by user interaction.
+            return skip && *skip;
+        }
+        // For same-device rename, we update progress based on file/dir size.
+        const auto fromSize = fromInfo->attribute(DFileInfo::AttributeID::kStandardSize).toLongLong();
         workData->currentWriteSize += fromSize;
         if (fromInfo->attribute(DFileInfo::AttributeID::kStandardIsFile).toBool()) {
             workData->blockRenameWriteSize += fromSize;
-            workData->currentWriteSize += (fromSize > 0
-                                                   ? fromSize
-                                                   : FileUtils::getMemoryPageSize());
             if (fromSize <= 0)
                 workData->zeroOrlinkOrDirWriteSize += FileUtils::getMemoryPageSize();
-        } else {
-            // count size
+        } else {   // Directory
             SizeInfoPointer sizeInfo(new FileUtils::FilesSizeInfo);
             FileOperationsUtils::statisticFilesSize(fromInfo->uri(), sizeInfo);
             workData->blockRenameWriteSize += sizeInfo->totalSize;
             if (sizeInfo->totalSize <= 0)
                 workData->zeroOrlinkOrDirWriteSize += workData->dirSize;
         }
-        QUrl orignalUrl = fromInfo->uri();
-        if (isTrashFile) {
-            removeTrashInfo(trashInfoUrl);
-            orignalUrl.setScheme("trash");
-            orignalUrl.setPath("/" + orignalUrl.path().replace("/", "\\"));
-            auto tmpFileName = fromInfo->uri().fileName();
-            auto orignalName = QUrl::toPercentEncoding(tmpFileName);
-            orignalUrl.setPath(orignalUrl.path().replace(tmpFileName, orignalName));
+    } else {
+        // Cross-device: fall back to copy-then-delete.
+        fmInfo() << "Cross-device move detected, using copy-delete fallback - from:" << fromInfo->uri() << "to:" << targetPathInfo->uri();
+        toInfo = doCheckFile(fromInfo, targetPathInfo, fileName, skip);
+        if (toInfo.isNull()) {
+            return skip && *skip;
         }
-        if (toInfo)
-            emit fileRenamed(orignalUrl, toInfo->uri());
-        return true;
+        success = copyAndDeleteFile(fromInfo, targetPathInfo, toInfo, skip);
+        if (success) {
+            const auto fromSize = fromInfo->attribute(DFileInfo::AttributeID::kStandardSize).toLongLong();
+            workData->currentWriteSize += fromSize;
+        }
+    }
+
+    if (!success) {
+        if (stopWork.load())
+            stopWork.store(false);
+        return false;
     }
 
     if (stopWork.load()) {
@@ -186,15 +198,10 @@ bool DoCutFilesWorker::doCutFile(const DFileInfoPointer &fromInfo, const DFileIn
         return false;
 
     if (toInfo.isNull()) {
-        fmWarning() << "Rename operation failed: cannot create target file info";
+        fmWarning() << "Operation failed: cannot create target file info";
         return false;
     }
 
-    fmInfo() << "Rename failed, using copy and delete method: from=" << fromInfo->uri() << "to=" << targetPathInfo->uri();
-    if (!copyAndDeleteFile(fromInfo, targetPathInfo, toInfo, skip))
-        return false;
-
-    workData->currentWriteSize += fromSize;
     QUrl orignalUrl = fromInfo->uri();
     if (isTrashFile) {
         removeTrashInfo(trashInfoUrl);
@@ -222,7 +229,7 @@ void DoCutFilesWorker::endWork()
         for (const auto &info : cutAndDeleteFiles) {
             bool ret = localFileHandler->deleteFile(info->uri());
             if (!ret) {
-                fmWarning() << "Delete file failed, stopping deletion of remaining files";
+                fmWarning() << "Failed to delete source file after cut - file:" << info->uri() << "error:" << localFileHandler->errorString();
                 continue;
             }
         }
@@ -245,7 +252,7 @@ bool DoCutFilesWorker::doMergDir(const DFileInfoPointer &fromInfo, const DFileIn
     QString error;
     const AbstractDirIteratorPointer &iterator = DirIteratorFactory::create<AbstractDirIterator>(fromInfo->uri(), &error);
     if (!iterator) {
-        fmCritical() << "Failed to create directory iterator, error:" << error;
+        fmCritical() << "Create directory iterator failed - dir:" << fromInfo->uri() << "error:" << error;
         doHandleErrorAndWait(fromInfo->uri(), toInfo->uri(), AbstractJobHandler::JobErrorType::kProrogramError);
         return false;
     }
@@ -313,47 +320,71 @@ bool DoCutFilesWorker::checkSelf(const DFileInfoPointer &fileInfo)
     return false;
 }
 
-bool DoCutFilesWorker::renameFileByHandler(const DFileInfoPointer &sourceInfo, const DFileInfoPointer &targetInfo)
+bool DoCutFilesWorker::renameFileByHandler(const DFileInfoPointer &sourceInfo, const DFileInfoPointer &targetInfo, bool *skip)
 {
     if (localFileHandler) {
         const QUrl &sourceUrl = sourceInfo->uri();
         const QUrl &targetUrl = targetInfo->uri();
-        return localFileHandler->renameFile(sourceUrl, targetUrl, false);
+        AbstractJobHandler::SupportAction action = AbstractJobHandler::SupportAction::kNoAction;
+
+        do {
+            action = AbstractJobHandler::SupportAction::kNoAction;
+            if (!localFileHandler->renameFile(sourceUrl, targetUrl, false)) {
+                auto err = AbstractJobHandler::JobErrorType::kPermissionError;
+                if (localFileHandler->errorCode() != DFMIOErrorCode::DFM_IO_ERROR_PERMISSION_DENIED) {
+                    err = AbstractJobHandler::JobErrorType::kUnknowError;
+                }
+                action = doHandleErrorAndWait(sourceUrl, targetUrl, err, false, localFileHandler->errorString());
+            }
+        } while (action == AbstractJobHandler::SupportAction::kRetryAction && !isStopped());
+
+        checkRetry();
+
+        if (action != AbstractJobHandler::SupportAction::kNoAction) {
+            setSkipValue(skip, action);
+            return false;
+        }
     }
-    return false;
+    return true;
 }
 
-DFileInfoPointer DoCutFilesWorker::doRenameFile(const DFileInfoPointer &sourceInfo,
-                                                const DFileInfoPointer &targetPathInfo,
-                                                const QString fileName, bool *ok, bool *skip)
+DFileInfoPointer DoCutFilesWorker::trySameDeviceRename(const DFileInfoPointer &sourceInfo,
+                                                       const DFileInfoPointer &targetPathInfo,
+                                                       const QString fileName, bool *ok, bool *skip)
 {
+    // This function assumes the source and target are on the same device.
+    // It handles name collision checks and performs the rename operation.
     const QUrl &sourceUrl = sourceInfo->uri();
-    if (DFMIO::DFMUtils::deviceNameFromUrl(sourceUrl) == DFMIO::DFMUtils::deviceNameFromUrl(targetOrgUrl)) {
-        auto newTargetInfo = doCheckFile(sourceInfo, targetPathInfo, fileName, skip);
-        if (newTargetInfo.isNull())
-            return nullptr;
+    fmDebug() << "Attempting same-device rename - from:" << sourceUrl << "to:" << targetPathInfo->uri();
+    auto newTargetInfo = doCheckFile(sourceInfo, targetPathInfo, fileName, skip);
+    if (newTargetInfo.isNull())
+        return nullptr;
 
-        emitCurrentTaskNotify(sourceUrl, newTargetInfo->uri());
-        bool result = false;
-        if (isCutMerge) {
-            newTargetInfo->initQuerier();
-            isCutMerge = false;
-            result = doMergDir(sourceInfo, newTargetInfo, skip);
-        } else {
-            result = renameFileByHandler(sourceInfo, newTargetInfo);
-        }
-
-        if (result) {
-            if (targetPathInfo == this->targetInfo) {
-                completeSourceFiles.append(sourceUrl);
-                completeTargetFiles.append(newTargetInfo->uri());
+    emitCurrentTaskNotify(sourceUrl, newTargetInfo->uri());
+    bool result = false;
+    if (isCutMerge) {
+        newTargetInfo->initQuerier();
+        isCutMerge = false;
+        result = doMergDir(sourceInfo, newTargetInfo, skip);
+    } else {
+        if (newTargetInfo->exists()) {
+            result = deleteFile(newTargetInfo->uri(), newTargetInfo->uri(), skip);
+            if (result) {
+                *skip = false;   // deleteFile拷贝成功会设置skip为true，正确的删除后设置skip为false
+                result = renameFileByHandler(sourceInfo, newTargetInfo, skip);
             }
+        } else {
+            result = renameFileByHandler(sourceInfo, newTargetInfo, skip);
         }
-        if (ok)
-            *ok = result;
-        return newTargetInfo;
     }
 
-    auto newTargetInfo = doCheckFile(sourceInfo, targetPathInfo, fileName, ok);
+    if (result) {
+        if (targetPathInfo == this->targetInfo) {
+            completeSourceFiles.append(sourceUrl);
+            completeTargetFiles.append(newTargetInfo->uri());
+        }
+    }
+    if (ok)
+        *ok = result;
     return newTargetInfo;
 }
