@@ -42,9 +42,9 @@ void AbstractWorker::setWorkArgs(const JobHandlePointer handle, const QList<QUrl
         fmCritical() << "Job handle pointer is null, cannot set work arguments";
         return;
     }
-    
+
     fmInfo() << "Setting work arguments - sources count:" << sources.count() << "target:" << target;
-    
+
     connect(this, &AbstractWorker::startWork, this, &AbstractWorker::doWork);
     workData.reset(new WorkerData);
     workData->dirSize = FileUtils::getMemoryPageSize();
@@ -88,13 +88,6 @@ void AbstractWorker::doOperateWork(AbstractJobHandler::SupportActions actions, A
     if (id == quintptr(this)) {
         return resume();
     }
-
-    for (auto worker : threadCopyWorker) {
-        if (id == quintptr(worker.data())) {
-            worker->operateAction(currentAction);
-            return;
-        }
-    }
 }
 
 /*!
@@ -106,13 +99,11 @@ void AbstractWorker::stop()
     if (statisticsFilesSizeJob)
         statisticsFilesSizeJob->stop();
 
-    if (updateProgressTimer)
-        updateProgressTimer->stopTimer();
-
-    if (updateProgressThread) {
-        updateProgressThread->quit();
-        updateProgressThread->wait();
+    if (updateProgressTimer) {
+        // Stop timer in main thread using cross-thread method invocation
+        QMetaObject::invokeMethod(updateProgressTimer.data(), "stopTimer", Qt::QueuedConnection);
     }
+
     waitCondition.wakeAll();
 }
 /*!
@@ -166,6 +157,8 @@ void AbstractWorker::getAction(AbstractJobHandler::SupportActions actions)
         retry = workData->signalThread ? false : true;
     } else if (actions.testFlag(AbstractJobHandler::SupportAction::kEnforceAction)) {
         currentAction = AbstractJobHandler::SupportAction::kEnforceAction;
+    } else if (actions.testFlag(AbstractJobHandler::SupportAction::kPermanentlyDelete)) {
+        currentAction = AbstractJobHandler::SupportAction::kPermanentlyDelete;
     } else {
         currentAction = AbstractJobHandler::SupportAction::kNoAction;
     }
@@ -176,6 +169,22 @@ QUrl AbstractWorker::parentUrl(const QUrl &url)
     return FileOperationsUtils::parentUrl(url);
 }
 
+void AbstractWorker::syncFilesToDevice()
+{
+    // Check if sync is needed (needsSync now excludes exBlockSyncEveryWrite condition)
+    if (!needsSync())
+        return;
+
+    // Decide sync type based on exBlockSyncEveryWrite flag
+    if (workData && workData->exBlockSyncEveryWrite) {
+        // Blocking sync
+        performSync();
+    } else {
+        // Non-blocking sync via D-Bus
+        performAsyncSync();
+    }
+}
+
 FileInfo::FileType AbstractWorker::fileType(const DFileInfoPointer &info)
 {
     FileInfo::FileType fileType { FileInfo::FileType::kUnknown };
@@ -212,15 +221,12 @@ FileInfo::FileType AbstractWorker::fileType(const DFileInfoPointer &info)
  */
 void AbstractWorker::startCountProccess()
 {
-    if (!updateProgressTimer)
-        updateProgressTimer.reset(new UpdateProgressTimer());
-    if (!updateProgressThread)
-        updateProgressThread.reset(new QThread);
-    updateProgressTimer->moveToThread(updateProgressThread.data());
-    updateProgressThread->start();
-    connect(this, &AbstractWorker::startUpdateProgressTimer, updateProgressTimer.data(), &UpdateProgressTimer::doStartTime);
-    connect(updateProgressTimer.data(), &UpdateProgressTimer::updateProgressNotify, this, &AbstractWorker::onUpdateProgress, Qt::DirectConnection);
-    emit startUpdateProgressTimer();
+    if (updateProgressTimer) {
+        // Start timer in main thread using cross-thread method invocation
+        // Signal-slot connection was already established in constructor
+        QMetaObject::invokeMethod(updateProgressTimer.data(), "doStartTime", Qt::QueuedConnection);
+        fmDebug() << "Progress timer started via cross-thread method invocation";
+    }
 }
 /*!
  * \brief AbstractWorker::statisticsFilesSize statistics source files size
@@ -249,6 +255,9 @@ bool AbstractWorker::statisticsFilesSize()
         isSourceFileLocal = fsType.startsWith("ext");
     }
 
+    // Set workData flags for use in DoCopyFileWorker
+    workData->isSourceFileLocal = isSourceFileLocal;
+
     if (isSourceFileLocal) {
         fmDebug() << "Using synchronous file size calculation for local files";
         const SizeInfoPointer &fileSizeInfo = FileOperationsUtils::statisticsFilesSize(sourceUrls, true);
@@ -269,11 +278,12 @@ bool AbstractWorker::statisticsFilesSize()
     return true;
 }
 /*!
- * \brief AbstractWorker::copyWait Blocking waiting for task
+ * \brief AbstractWorker::workerWait Blocking waiting for task
  * \return Is it running
  */
 bool AbstractWorker::workerWait()
 {
+    QMutexLocker locker(&mutex);
     waitCondition.wait(&mutex);
 
     return currentState == AbstractJobHandler::JobState::kRunningState;
@@ -316,8 +326,9 @@ bool AbstractWorker::initArgs()
  */
 void AbstractWorker::endWork()
 {
-    setStat(AbstractJobHandler::JobState::kStopState);
+    syncFilesToDevice();
 
+    setStat(AbstractJobHandler::JobState::kStopState);
     Q_EMIT removeTaskWidget();
 
     // send finish signal
@@ -335,7 +346,7 @@ void AbstractWorker::endWork()
     fmInfo() << "Work completed - job type:" << static_cast<int>(jobType)
              << "completed files:" << completeSourceFiles.count()
              << "time elapsed:" << timeElapsed.elapsed() << "ms";
-             
+
     if (statisticsFilesSizeJob) {
         statisticsFilesSizeJob->stop();
         statisticsFilesSizeJob->wait();
@@ -417,10 +428,10 @@ void AbstractWorker::emitErrorNotify(const QUrl &from, const QUrl &to, const Abs
     info->insert(AbstractJobHandler::NotifyInfoKey::kWorkerPointer, QVariant::fromValue(emitId));
     emit errorNotify(info);
 
-    fmWarning() << "Work error occurred - job type:" << static_cast<int>(jobType) 
-                << "error type:" << static_cast<int>(error) 
-                << "source:" << from 
-                << "target:" << to 
+    fmWarning() << "Work error occurred - job type:" << static_cast<int>(jobType)
+                << "error type:" << static_cast<int>(error)
+                << "source:" << from
+                << "target:" << to
                 << "message:" << errorMsg;
 }
 
@@ -456,20 +467,12 @@ void AbstractWorker::resumeAllThread()
     resume();
     if (copyOtherFileWorker)
         copyOtherFileWorker->resume();
-    for (auto worker : threadCopyWorker) {
-        worker->resume();
-    }
 }
 
 void AbstractWorker::resumeThread(const QList<quint64> &errorIds)
 {
     if (!errorIds.contains(quintptr(this)) && (!copyOtherFileWorker || !errorIds.contains(quintptr(copyOtherFileWorker.data()))))
         resume();
-
-    for (auto worker : threadCopyWorker) {
-        if (!errorIds.contains(quintptr(worker.data())))
-            worker->resume();
-    }
 }
 
 void AbstractWorker::pauseAllThread()
@@ -477,18 +480,12 @@ void AbstractWorker::pauseAllThread()
     pause();
     if (copyOtherFileWorker)
         copyOtherFileWorker->pause();
-    for (auto worker : threadCopyWorker) {
-        worker->pause();
-    }
 }
 
 void AbstractWorker::stopAllThread()
 {
     if (copyOtherFileWorker)
         copyOtherFileWorker->stop();
-    for (auto worker : threadCopyWorker) {
-        worker->stop();
-    }
     stop();
 }
 
@@ -505,8 +502,8 @@ void AbstractWorker::checkRetry()
 bool AbstractWorker::doWork()
 {
     timeElapsed.start();
-    fmInfo() << "Starting work - job type:" << static_cast<int>(jobType) 
-             << "sources count:" << sourceUrls.count() 
+    fmInfo() << "Starting work - job type:" << static_cast<int>(jobType)
+             << "sources count:" << sourceUrls.count()
              << "target:" << targetUrl;
 
     // 执行拷贝的业务逻辑
@@ -560,7 +557,7 @@ void AbstractWorker::onStatisticsFilesSizeFinish()
     workData->dirSize = sizeInfo->dirSize;
     sourceFilesCount = sizeInfo->fileCount;
     allFilesList = sizeInfo->allFiles;
-    
+
     fmInfo() << "Asynchronous file statistics completed - total size:" << sourceFilesTotalSize << "file count:" << sourceFilesCount;
 }
 
@@ -577,6 +574,17 @@ AbstractWorker::AbstractWorker(QObject *parent)
         speedtimer = new QElapsedTimer();
         speedtimer->start();
     }
+
+    // Create updateProgressTimer in main thread to avoid cross-thread destruction warning
+    updateProgressTimer.reset(new UpdateProgressTimer());
+
+    // Pre-establish signal-slot connection in main thread
+    // Timer runs in main thread, use DirectConnection for immediate cross-thread call
+    if (updateProgressTimer) {
+        connect(updateProgressTimer.data(), &UpdateProgressTimer::updateProgressNotify,
+                this, &AbstractWorker::onUpdateProgress, Qt::DirectConnection);
+        fmDebug() << "Progress timer signal-slot connection established with DirectConnection";
+    }
 }
 /*!
  * \brief AbstractWorker::formatFileName Processing and formatting file names
@@ -648,7 +656,7 @@ void AbstractWorker::saveOperations()
             values.insert("redosources", QUrl::toStringList(completeSourceFiles));
             values.insert("redotargets", QUrl::toStringList(redoTargets));
             dpfSignalDispatcher->publish(GlobalEventType::kSaveOperator, values);
-            
+
             fmDebug() << "Saved operation for undo/redo - job type:" << static_cast<int>(jobType);
         }
     }
@@ -672,19 +680,16 @@ void AbstractWorker::saveOperations()
 
 AbstractWorker::~AbstractWorker()
 {
+    // Ensure all waiting threads are woken up before destruction
+    waitCondition.wakeAll();
+
     if (statisticsFilesSizeJob) {
         statisticsFilesSizeJob->stop();
         statisticsFilesSizeJob->wait();
     }
 
-    // 添加对 updateProgressThread 的清理
-    if (updateProgressThread) {
-        if (updateProgressThread->isRunning()) {
-            updateProgressThread->quit();
-            updateProgressThread->wait();
-        }
-        updateProgressThread.reset();  // 或者显式清理智能指针
-    }
+    // UpdateProgressTimer will be automatically cleaned up when destroyed
+    // No need for explicit cross-thread blocking call that can cause deadlock
 
     if (speedtimer) {
         delete speedtimer;
@@ -709,6 +714,6 @@ void AbstractWorker::initHandleConnects(const JobHandlePointer handle)
     connect(this, &AbstractWorker::speedUpdatedNotify, handle.get(), &AbstractJobHandler::onSpeedUpdated, Qt::QueuedConnection);
     connect(this, &AbstractWorker::currentTaskNotify, handle.get(), &AbstractJobHandler::onCurrentTask, Qt::QueuedConnection);
     connect(this, &AbstractWorker::requestTaskDailog, handle.get(), &AbstractJobHandler::requestTaskDailog, Qt::QueuedConnection);
-    
+
     fmDebug() << "Initialized handle connections";
 }
