@@ -46,6 +46,7 @@ const int CanvasItemDelegate::kTextPadding = 4;
 const int CanvasItemDelegate::kIconSpacing = 2;
 const int CanvasItemDelegate::kIconBackRadius = 18;
 const int CanvasItemDelegate::kIconRectRadius = 4;
+const int CanvasItemDelegate::kIconBackgroundMargin = 4;
 
 CanvasItemDelegatePrivate::CanvasItemDelegatePrivate(CanvasItemDelegate *qq)
     : q(qq)
@@ -132,8 +133,9 @@ void CanvasItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     // get item paint geomerty
     // the method to get rect for each element is equal to paintGeomertys(option, index);
     {
-        // draw icon
+        // draw icon and background
         const QRect rIcon = iconRect(option.rect);
+        paintBackground(painter, indexOption, rIcon);
         paintIcon(painter, indexOption.icon,
                   { rIcon,
                     Qt::AlignCenter,
@@ -607,7 +609,7 @@ QRect CanvasItemDelegate::labelRect(const QRect &paintRect, const QRect &usedRec
 {
     QRect lable = paintRect;
     // label rect is under the icon.
-    lable.setTop(usedRect.bottom());
+    lable.setTop(usedRect.bottom() + kIconBackgroundMargin);
 
     // minus text padding at left and right.
     lable.setWidth(paintRect.width() - 2 * kTextPadding);
@@ -749,18 +751,18 @@ QRectF CanvasItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, const
     Qt::Alignment alignment { visualAlignment(painter->layoutDirection(), opts.alignment) };
     const qreal pixelRatio = painter->device()->devicePixelRatioF();
     const QPixmap &px = getIconPixmap(icon, opts.rect.size().toSize(), pixelRatio, opts.mode, opts.state);
-    
+
     // 保持图标原始比例
     qreal w = px.width() / px.devicePixelRatio();
     qreal h = px.height() / px.devicePixelRatio();
-    
+
     // 如果图标大于目标区域，等比例缩放
     if (w > opts.rect.width() || h > opts.rect.height()) {
         qreal scale = qMin(opts.rect.width() / w, opts.rect.height() / h);
         w *= scale;
         h *= scale;
     }
-    
+
     qreal x = opts.rect.x();
     qreal y = opts.rect.y();
 
@@ -778,6 +780,26 @@ QRectF CanvasItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, const
         painter->setRenderHints(painter->renderHints() | QPainter::Antialiasing | QPainter::SmoothPixmapTransform, true);
 
         auto iconStyle { IconUtils::getIconStyle(opts.rect.size().toSize().width()) };
+
+        // 计算可用的图像绘制区域（减去阴影和边框）
+        QRectF availableRect = opts.rect;
+        availableRect.adjust(iconStyle.shadowRange, iconStyle.shadowRange, -iconStyle.shadowRange, -iconStyle.shadowRange);
+        availableRect.adjust(iconStyle.stroke, iconStyle.stroke, -iconStyle.stroke, -iconStyle.stroke);
+
+        // 计算缩略图的最佳显示尺寸 - 如果小于可用区域则放大铺满
+        qreal scaleX = availableRect.width() / (w > 0 ? w : 1);
+        qreal scaleY = availableRect.height() / (h > 0 ? h : 1);
+        qreal scale = qMin(scaleX, scaleY);
+
+        // 如果原图小于可用区域，则等比放大；否则保持原逻辑
+        if (scale > 1.0) {
+            w *= scale;
+            h *= scale;
+            // 重新计算居中位置
+            x = opts.rect.x() + (opts.rect.width() - w) / 2.0;
+            y = opts.rect.y() + (opts.rect.height() - h) / 2.0;
+        }
+
         QRectF backgroundRect { x, y, w, h };
         QRectF imageRect { backgroundRect };
 
@@ -821,6 +843,29 @@ QRectF CanvasItemDelegate::paintEmblems(QPainter *painter, const QRectF &rect, c
     return rect;
 }
 
+void CanvasItemDelegate::paintBackground(QPainter *painter, const QStyleOptionViewItem &option, const QRect &iconRect) const
+{
+    bool isSelected = (option.state & QStyle::State_Selected) && option.showDecorationSelected;
+    if (!isSelected)
+        return;
+
+    QColor backgroundColor(0, 0, 0, qRound(255 * 0.15));
+    QColor borderColor(255, 255, 255, qRound(255 * 0.1));
+    QRect backgroundRect = iconRect.adjusted(-kIconBackgroundMargin, -kIconBackgroundMargin, kIconBackgroundMargin, kIconBackgroundMargin);
+
+    painter->save();
+    painter->setRenderHint(QPainter::Antialiasing);
+
+    QPainterPath path;
+    path.addRoundedRect(backgroundRect, kIconRectRadius, kIconRectRadius);
+    painter->fillPath(path, backgroundColor);
+
+    painter->setPen(borderColor);
+    painter->drawPath(path);
+
+    painter->restore();
+}
+
 void CanvasItemDelegatePrivate::extendLayoutText(const FileInfoPointer &info, dfmbase::ElideTextLayout *layout)
 {
     // extend layout
