@@ -23,7 +23,7 @@ Q_DECLARE_METATYPE(QList<QUrl> *)
 Q_DECLARE_METATYPE(QList<QVariantMap> *);
 
 namespace dfmplugin_avfsbrowser {
-DFM_LOG_REISGER_CATEGORY(DPAVFSBROWSER_NAMESPACE)
+DFM_LOG_REGISTER_CATEGORY(DPAVFSBROWSER_NAMESPACE)
 
 DFMBASE_USE_NAMESPACE
 
