@@ -167,6 +167,9 @@ void ComputerMenuScene::updateState(QMenu *parent)
         if (d->info->targetUrl().isValid())
             keeped << kUnmount;
 
+        if (d->info->renamable())
+            keeped << kRename;
+
         auto id = d->info->extraProperty(DeviceProperty::kId).toString();
         if (id.contains(QRegularExpression("^smb|^ftp|^sftp|^dav")) || ProtocolUtils::isSMBFile(QUrl(id)))
             keeped << kLogoutAndForget;
@@ -176,6 +179,8 @@ void ComputerMenuScene::updateState(QMenu *parent)
     case AbstractEntryFileEntity::kOrderGPhoto2:
     case AbstractEntryFileEntity::kOrderFiles: {
         keeped = QStringList { kOpenInNewWin, kOpenInNewTab, kUnmount, kProperty };
+        if (d->info->renamable())
+            keeped << kRename;
     } break;
     case AbstractEntryFileEntity::kOrderApps:
         keeped = QStringList { kOpen };
