@@ -129,6 +129,15 @@ void ComputerView::setStatusBarHandler(ComputerStatusBar *sb)
     dp->statusBar = sb;
 }
 
+void ComputerView::setRowHidden(int row, bool hide)
+{
+    // 更新item的可见性状态，避免view隐藏了但绘制时仍然绘制该item的问题
+    // 在某些性能较差的机器上，通过view隐藏item后，若在delegate中进行了
+    // 设值操作（model()->data()），可能会绘制本该隐藏的item，造成显示问题
+    model()->setData(model()->index(row, 0), !hide, ComputerModel::DataRoles::kItemVisibleRole);
+    DListView::setRowHidden(row, hide);
+}
+
 void ComputerView::showEvent(QShowEvent *event)
 {
     QApplication::restoreOverrideCursor();
@@ -193,10 +202,7 @@ void ComputerView::initConnect()
     connect(this->selectionModel(), &QItemSelectionModel::selectionChanged, this, &ComputerView::onSelectionChanged);
 
     connect(ComputerControllerInstance, &ComputerController::requestRename, this, &ComputerView::onRenameRequest);
-    connect(ComputerControllerInstance, &ComputerController::updateItemAlias, this, [this](const QUrl &url) {
-        int row = computerModel()->findItem(url);
-        this->update(computerModel()->index(row, 0));
-    });
+    connect(ComputerControllerInstance, &ComputerController::updateItemAlias, this, &ComputerView::onUpdateItemAlias);
 
     connect(ComputerItemWatcherInstance, &ComputerItemWatcher::updatePartitionsVisiable, this, &ComputerView::handleComputerItemVisible);
     connect(ComputerItemWatcherInstance, &ComputerItemWatcher::hideFileSystemTag, this, [this]() { this->update(); });
@@ -289,6 +295,51 @@ void ComputerView::onRenameRequest(quint64 winId, const QUrl &url)
         edit(idx);
 }
 
+void ComputerView::onUpdateItemAlias(const QUrl &url, const QString &alias, bool isProtocol)
+{
+    if (isProtocol) {
+        DFMEntryFileInfoPointer info(new EntryFileInfo(url));
+        const auto &itemList = computerModel()->itemList();
+        for (const auto &item : itemList) {
+            if (item.shape == ComputerItemData::kSplitterItem || !item.info)
+                continue;
+
+            if (info->targetUrl().scheme() != item.info->targetUrl().scheme()
+                || info->targetUrl().host() != item.info->targetUrl().host())
+                continue;
+
+            QVariantMap map {
+                { "Property_Key_DisplayName", item.info->displayName() },
+                { "Property_Key_EditDisplayText", item.info->editDisplayText() },
+                { "Property_Key_Editable", true }
+            };
+
+            dpfSlotChannel->push("dfmplugin_sidebar", "slot_Item_Update", item.info->urlOf(UrlInfoType::kUrl), map);
+            dpfSlotChannel->push("dfmplugin_titlebar", "slot_Crumb_Update", item.info->urlOf(UrlInfoType::kUrl));
+            ComputerEventCaller::sendItemRenamed(item.info->urlOf(UrlInfoType::kUrl), alias);
+
+            int row = computerModel()->findItem(item.info->urlOf(UrlInfoType::kUrl));
+            this->update(computerModel()->index(row, 0));
+        }
+    } else {
+        const auto &item = computerModel()->findItemData(url);
+        if (!item.info)
+            return;
+
+        // update sidebar
+        QString sidebarName = alias.isEmpty() ? item.info->displayName() : alias;
+        QVariantMap map {
+            { "Property_Key_DisplayName", sidebarName },
+            { "Property_Key_Editable", true }
+        };
+        dpfSlotChannel->push("dfmplugin_sidebar", "slot_Item_Update", item.info->urlOf(UrlInfoType::kUrl), map);
+        dpfSlotChannel->push("dfmplugin_titlebar", "slot_Tab_SetAlias", item.info->targetUrl(), alias);
+
+        int row = computerModel()->findItem(url);
+        this->update(computerModel()->index(row, 0));
+    }
+}
+
 void ComputerView::handleDisksVisible()
 {
     /* NOTE(xust): disks hidden by dconfig is treat as disks hidden by HintIgnore.
