@@ -6,6 +6,7 @@
 #define ABSTRACTSEARCHER_H
 
 #include "dfmplugin_search_global.h"
+#include "searchresult_define.h"
 
 #include <QObject>
 #include <QUrl>
@@ -27,9 +28,14 @@ public:
     virtual bool search() = 0;
     virtual void stop() = 0;
     virtual bool hasItem() const = 0;
-    virtual QList<QUrl> takeAll() = 0;
+    virtual DFMSearchResultMap takeAll() = 0;
+    
+    // 为向后兼容保留的接口
+    virtual QList<QUrl> takeAllUrls();
+
 signals:
     void unearthed(AbstractSearcher *searcher);
+    void finished();
 
 protected:
     QUrl searchUrl;
