@@ -6,9 +6,11 @@
 #define SEARCHMANAGER_H
 
 #include "dfmplugin_search_global.h"
+#include "searchmanager/searcher/searchresult_define.h"
 
 #include <QObject>
 #include <QMap>
+#include <QMultiMap>
 
 namespace dfmplugin_search {
 
@@ -23,7 +25,13 @@ public:
 
     void init();
     bool search(quint64 winId, const QString &taskId, const QUrl &url, const QString &keyword);
-    QList<QUrl> matchedResults(const QString &taskId);
+    
+    // 获取统一的搜索结果数据
+    DFMSearchResultMap matchedResults(const QString &taskId);
+    
+    // 为向后兼容保留的接口，只获取URL列表
+    QList<QUrl> matchedResultUrls(const QString &taskId);
+    
     void stop(const QString &taskId);
     void stop(quint64 winId);
 
@@ -45,7 +53,9 @@ private:
     ~SearchManager();
 
     MainController *mainController = nullptr;
-    QMap<quint64, QString> taskIdMap;
+    QMap<quint64, QString> taskIdMap;  // 当前窗口最近一次的搜索taskId
+    QMultiMap<quint64, QString> winTasksMap;  // 窗口ID对应的所有搜索任务ID
+    QMap<QString, QPair<QUrl, QString>> taskInfoMap; // 保存任务ID对应的url和keyword
 };
 
 }
