@@ -14,6 +14,7 @@
 #include <dfm-base/utils/fileutils.h>
 #include <dfm-base/dbusservice/global_server_defines.h>
 #include <dfm-base/base/device/deviceutils.h>
+#include <dfm-base/base/device/devicealiasmanager.h>
 
 #ifdef DTKWIDGET_CLASS_DSizeMode
 #    include <DSizeMode>
@@ -53,6 +54,7 @@ static constexpr int kItemMargin = 10;
 static constexpr int kItemIconSize = 16;
 static constexpr int kEjectIconSize = 16;
 static constexpr int kEmptyItemSize = 10;
+static constexpr int kDefaultMaxLength = 40;
 
 #ifdef DTKWIDGET_CLASS_DSizeMode
 static constexpr int kCompactExpandIconSize = 10;
@@ -91,6 +93,8 @@ void SideBarItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
     else
         opt.state &= (~QStyle::State_Active);
 
+    const bool isActive = opt.widget && opt.widget->isActiveWindow();
+
     painter->setRenderHint(QPainter::Antialiasing);
 
     if (!option.widget)
@@ -134,14 +138,16 @@ void SideBarItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
 
     // Draw the background color when dragging files, rather than when dragging an item
     if ((selected && isDragedItem) || keepDrawingHighlighted) {   // Draw selected background
-        QPalette::ColorGroup colorGroup = QPalette::Normal;
-        QColor bgColor = option.palette.color(colorGroup, QPalette::Highlight);
-
+        QColor bgColor;
         if (isDraggingItemNotHighlighted) {
             if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType)
                 bgColor = DGuiApplicationHelper::adjustColor(widgetColor, 0, 0, 5, 0, 0, 0, 0);
             else
                 bgColor = QColor(230, 230, 230);
+        } else {
+            bgColor = option.palette.color(QPalette::Active, QPalette::Highlight);
+            if (!isActive)
+                bgColor.setAlpha(102);
         }
 
         painter->setBrush(bgColor);
@@ -193,10 +199,15 @@ void SideBarItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         separatorTextColor = QColor(0, 0, 0, 76);   // alpha 30%
     }
     painter->setPen(separatorItem ? separatorTextColor : qApp->palette().color(QPalette::ColorRole::Text));
-    if (iconMode == QIcon::Selected)
-        painter->setPen(opt.widget->isActiveWindow() ? Qt::white : opt.palette.color(cg, QPalette::HighlightedText));
-    if (iconMode != QIcon::Selected && !opt.widget->isActiveWindow())
-        painter->setPen(opt.palette.color(cg, QPalette::Text));
+    if (iconMode == QIcon::Selected) {
+        QColor finalTextColor = opt.palette.color(QPalette::Active, QPalette::HighlightedText);
+        if (!isActive)
+            finalTextColor.setAlpha(102);
+        painter->setPen(finalTextColor);
+    } else if (!isActive) {
+        const QColor c = opt.palette.color(cg, QPalette::Text);
+        painter->setPen(c);
+    }
 
     QString text = index.data().toString();
     qreal baseValue = itemRect.width() - iconSize.width() - 2 * kItemMargin;
@@ -268,26 +279,36 @@ QWidget *SideBarItemDelegate::createEditor(QWidget *parent, const QStyleOptionVi
     SideBarItem *tgItem = sidebarModel->itemFromIndex(index);
     if (!tgItem)
         return nullptr;
-    auto sourceInfo = InfoFactory::create<FileInfo>(tgItem->url(), Global::CreateFileInfoType::kCreateFileInfoSync);
-    if (!sourceInfo)
-        return nullptr;
-    if (!sourceInfo->exists())
-        return nullptr;
     QWidget *editor = DStyledItemDelegate::createEditor(parent, option, index);
     QLineEdit *qle = nullptr;
     if ((qle = dynamic_cast<QLineEdit *>(editor))) {
-        QRegularExpression regx(GlobalPrivate::kRegPattern);
-        QValidator *validator = new QRegularExpressionValidator(regx, qle);
-        qle->setValidator(validator);
+        if (!NPDeviceAliasManager::instance()->canSetAlias(tgItem->targetUrl())) {
+            QRegularExpression regx(GlobalPrivate::kRegPattern);
+            QValidator *validator = new QRegularExpressionValidator(regx, qle);
+            qle->setValidator(validator);
+        }
 
-        connect(qle, &QLineEdit::textChanged, this, [this, sourceInfo](const QString &text) {
-            onEditorTextChanged(text, sourceInfo);
+        connect(qle, &QLineEdit::textChanged, this, [this, tgItem](const QString &text) {
+            onEditorTextChanged(text, tgItem);
         });
     }
 
     return editor;
 }
 
+void SideBarItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
+{
+    auto currEditor = qobject_cast<QLineEdit *>(editor);
+    if (currEditor && index.isValid()) {
+        DStandardItem *item = qobject_cast<const SideBarModel *>(index.model())->itemFromIndex(index);
+        SideBarItem *sidebarItem = static_cast<SideBarItem *>(item);
+        if (sidebarItem) {
+            const auto &info = sidebarItem->itemInfo();
+            currEditor->setText(info.editDisplayText.isEmpty() ? info.displayName : info.editDisplayText);
+        }
+    }
+}
+
 void SideBarItemDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(index);
@@ -353,24 +374,28 @@ bool SideBarItemDelegate::editorEvent(QEvent *event, QAbstractItemModel *model,
     return QStyledItemDelegate::editorEvent(event, model, option, index);
 }
 
-void SideBarItemDelegate::onEditorTextChanged(const QString &text, const FileInfoPointer &info) const
+void SideBarItemDelegate::onEditorTextChanged(const QString &text, SideBarItem *item) const
 {
     QLineEdit *editor = qobject_cast<QLineEdit *>(sender());
     if (!editor)
         return;
 
-    int maxLen = INT_MAX;
+    int maxLen = kDefaultMaxLength;
     bool useCharCount = false;
-    const QString &fs = info->extraProperties()[GlobalServerDefines::DeviceProperty::kFileSystem].toString();
-    if (fs.isEmpty()) {
-        const auto &url = info->urlOf(FileInfo::FileUrlInfoType::kUrl);
-        if (url.isLocalFile()) {
-            maxLen = NAME_MAX;
-            const auto &path = url.path();
-            useCharCount = path.isEmpty() ? false : FileUtils::supportLongName(url);
+
+    auto info = InfoFactory::create<FileInfo>(item->url(), Global::CreateFileInfoType::kCreateFileInfoSync);
+    if (info && info->exists()) {
+        const QString &fs = info->extraProperties()[GlobalServerDefines::DeviceProperty::kFileSystem].toString();
+        if (fs.isEmpty()) {
+            const auto &url = info->urlOf(FileInfo::FileUrlInfoType::kUrl);
+            if (url.isLocalFile()) {
+                maxLen = NAME_MAX;
+                const auto &path = url.path();
+                useCharCount = path.isEmpty() ? false : FileUtils::supportLongName(url);
+            }
+        } else {
+            maxLen = FileUtils::supportedMaxLength(fs);
         }
-    } else {
-        maxLen = FileUtils::supportedMaxLength(fs);
     }
 
     QString dstText = text;
@@ -395,8 +420,9 @@ void SideBarItemDelegate::drawIcon(const QStyleOptionViewItem &option,
                                    QPalette::ColorGroup cg,
                                    bool keepHighlighted) const
 {
-    if (option.state & QStyle::State_Selected) {
-        painter->setPen(option.palette.color(cg, QPalette::HighlightedText));
+    const bool isActive = option.widget && option.widget->isActiveWindow();
+    if (iconMode == QIcon::Selected) {
+        painter->setPen(option.palette.color(QPalette::Active, QPalette::HighlightedText));
     } else {
         painter->setPen(option.palette.color(cg, QPalette::Text));
     }
@@ -406,6 +432,17 @@ void SideBarItemDelegate::drawIcon(const QStyleOptionViewItem &option,
     QPointF iconTopLeft = itemRect.topLeft() + QPointF(iconDx, iconDy);
     QRect iconRect(iconTopLeft.toPoint(), iconSize);
 
+    painter->save();
+    if (iconMode == QIcon::Selected && !isActive) {
+        painter->setOpacity(0.4);
+    }
+
+    // 若为“按下未松开但未选中”的过渡态，属于非Selected状态
+    bool pressedNotSelected = (option.state & QStyle::State_Sunken) && iconMode != QIcon::Selected;
+    QStyleOptionViewItem optForIcon = option;
+    if (pressedNotSelected)
+        optForIcon.state &= ~QStyle::State_Selected;
+
     QVariant icon = index.data(Qt::DecorationRole);
     DDciIcon dciIcon;
     if (icon.canConvert<DTK_GUI_NAMESPACE::DDciIcon>())
@@ -414,8 +451,10 @@ void SideBarItemDelegate::drawIcon(const QStyleOptionViewItem &option,
         QIcon::State state = option.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
         option.icon.paint(painter, iconRect, option.decorationAlignment, iconMode, state);
     } else {
-        drawDciIcon(option, painter, dciIcon, iconRect, cg, keepHighlighted);
+        drawDciIcon(optForIcon, painter, dciIcon, iconRect, cg, keepHighlighted);
     }
+    
+    painter->restore();
 
     // draw ejectable device icon
     if (isEjectable) {
@@ -453,8 +492,10 @@ void SideBarItemDelegate::drawDciIcon(const QStyleOptionViewItem &option, QPaint
     DDciIcon::Theme theme = appTheme == DGuiApplicationHelper::LightType ? DDciIcon::Light : DDciIcon::Dark;
     DDciIconPalette palette { option.palette.color(cg, QPalette::WindowText), option.palette.color(cg, QPalette::Window),
                               option.palette.color(cg, QPalette::Highlight), option.palette.color(cg, QPalette::HighlightedText) };
-    if (keepHighlighted)
-        palette.setForeground(option.palette.color(cg, QPalette::HighlightedText));
+    if ((option.state & QStyle::State_Selected) || keepHighlighted) {
+        const QColor fg = painter->pen().color();
+        palette.setForeground(fg);
+    }
     dciIcon.paint(painter, iconRect, painter->device() ? painter->device()->devicePixelRatioF() : qApp->devicePixelRatio(),
                   theme, mode, Qt::AlignCenter, palette);
 }
