@@ -196,15 +196,21 @@ void OptionButtonBox::onUrlChanged(const QUrl &url)
         // Store the state-based visibility
         d->listViewEnabled = !(state & OptionButtonManager::kHideListViewBtn);
         d->iconViewEnabled = !(state & OptionButtonManager::kHideIconViewBtn);
-        d->treeViewEnabled = d->treeViewButton && !(state & OptionButtonManager::kHideTreeViewBtn);
+        // 判断是否需要禁用树视图按钮
+        const bool needDisableTreeBtn = state & OptionButtonManager::kHideTreeViewBtn;
+        // 保持按钮可见，但根据需要禁用它
+        d->treeViewEnabled = d->treeViewButton;
         d->sortByEnabled = !(state & OptionButtonManager::kHideDetailSpaceBtn);
         d->viewOptionsEnabled = !(state & OptionButtonManager::kHideDetailSpaceBtn);
 
         // Apply the state visibility
         d->listViewButton->setHidden(!d->listViewEnabled);
         d->iconViewButton->setHidden(!d->iconViewEnabled);
-        if (d->treeViewButton)
-            d->treeViewButton->setHidden(!d->treeViewEnabled);
+        if (d->treeViewButton) {
+            // 不隐藏按钮，只是在需要时禁用它
+            d->treeViewButton->setHidden(false);
+            d->treeViewButton->setEnabled(!needDisableTreeBtn);
+        }
         d->sortByButton->setHidden(!d->sortByEnabled);
         d->viewOptionsButton->setVisible(d->viewOptionsEnabled);
 
@@ -212,7 +218,7 @@ void OptionButtonBox::onUrlChanged(const QUrl &url)
             setContentsMargins(0, 0, 0, 0);
             d->compactButton->hide();
         } else {
-            setContentsMargins(5, 0, 15, 0);
+            setContentsMargins(5, 0, 0, 0);
         }
     } else {
         fmDebug() << "No visibility state found for scheme, showing all buttons";
@@ -223,13 +229,16 @@ void OptionButtonBox::onUrlChanged(const QUrl &url)
         d->sortByEnabled = true;
         d->viewOptionsEnabled = true;
 
-        if (d->treeViewButton)
+        if (d->treeViewButton) {
             d->treeViewButton->setHidden(false);
+            // 正常状态下，确保启用树视图按钮
+            d->treeViewButton->setEnabled(true);
+        }
         d->listViewButton->setHidden(false);
         d->iconViewButton->setHidden(false);
         d->sortByButton->setHidden(false);
         d->viewOptionsButton->setHidden(false);
-        setContentsMargins(5, 0, 15, 0);
+        setContentsMargins(5, 0, 0, 0);
     }
 
     // Update button box size according to the parent widget width
@@ -253,7 +262,7 @@ void OptionButtonBox::initializeUi()
     QSize buttonSize(kToolButtonSize, kToolButtonSize);
     QSize buttonIconSize(kToolButtonIconSize, kToolButtonIconSize);
 
-    setContentsMargins(5, 0, 5, 0);
+    setContentsMargins(5, 0, 0, 0);
     d->buttonGroup = new QButtonGroup(this);
 
     d->iconViewButton = new CustomDToolButton;
@@ -314,7 +323,7 @@ void OptionButtonBox::initializeUi()
     d->viewOptionsButton->setIconSize(buttonIconSize);
     d->viewOptionsButton->setCheckable(false);
 
-    d->compactButton = new DToolButton(this);
+    d->compactButton = new CustomDToolButton(this);
     d->compactButton->setPopupMode(DToolButton::InstantPopup);
     d->compactButton->setFixedSize(48, kToolButtonSize);
     d->compactButton->setIconSize(QSize(kToolButtonIconSize, kToolButtonIconSize));
@@ -404,7 +413,7 @@ void OptionButtonBox::initUiForSizeMode()
     }
     d->hBoxLayout->addWidget(d->viewOptionsButton);
 
-    // Add stretch to push sortByButton to the right and keep its position fixed
+    // Add controlled stretch to push sortByButton to the right while limiting total spacing
     d->hBoxLayout->addStretch(1);
 
     // Add sortByButton (right side - position will remain fixed)
@@ -421,6 +430,7 @@ void OptionButtonBox::updateFixedWidth()
     if (d->isCompactMode) {
         fixedWidth += 48;   // Compact button width
         fixedWidth += 10;   // Spacing after compact button
+        fixedWidth -= 20;
     } else {
         fixedWidth += 10;   // Spacing after compact button, using their actual width
         // Only count visible view mode buttons (each is kToolButtonSize = 30)
@@ -436,8 +446,9 @@ void OptionButtonBox::updateFixedWidth()
     if (d->viewOptionsEnabled && d->viewOptionsButton && !d->viewOptionsButton->isHidden())
         fixedWidth += kToolButtonSize;
 
-    // Minimum spacing for stretch area (to ensure sortByButton stays on right)
-    fixedWidth += 20;   // Minimum stretch space
+    // Small fixed spacing + controlled stretch space to achieve ~15px total
+    fixedWidth += 5;   // Fixed spacing before stretch
+    // fixedWidth += 10;   // Controlled stretch space (5px + 10px = 15px total)
 
     // SortByButton (right side - width is 46 when visible)
     if (d->sortByEnabled && d->sortByButton && !d->sortByButton->isHidden())
