@@ -44,12 +44,11 @@ class AddressBarPrivate : public QObject
     QTimer timer;
     QVariantAnimation animation;
     QString placeholderText { tr("Enter address") };
-    QAction indicatorAction;
     QAction clearAction;
     QString completerBaseString;
     QString lastEditedString;
     int lastPressedKey { Qt::Key_D };   // just an init value
-    int lastPreviousKey { Qt::Key_Control };   //记录上前一个按钮
+    int lastPreviousKey { Qt::Key_Control };   // 记录上前一个按钮
     int selectPosStart { 0 };
     CrumbInterface *crumbController { nullptr };
     CompleterViewModel completerModel;
@@ -82,17 +81,13 @@ public:
     void completeLocalPath(const QString &text, const QUrl &url, int slashIndex);
 
 public Q_SLOTS:
-    void startSpinner();
-    void stopSpinner();
     void onTextEdited(const QString &text);
     void onReturnPressed();
     void insertCompletion(const QString &completion);
     void onCompletionHighlighted(const QString &highlightedCompletion);
-    void updateIndicatorIcon();
     void onCompletionModelCountChanged();
     void appendToCompleterModel(const QStringList &stringList);
     void onTravelCompletionListFinished();
-    void onIndicatorTriggerd();
 
 protected:
     virtual bool eventFilterHide(AddressBar *addressbar, QHideEvent *event);
@@ -101,4 +96,4 @@ protected:
 
 }
 
-#endif   //AddressBar_P_H
+#endif   // AddressBar_P_H
