@@ -11,14 +11,17 @@ using namespace dfmplugin_vault;
 VaultFileWatcherPrivate::VaultFileWatcherPrivate(const QUrl &fileUrl, VaultFileWatcher *qq)
     : AbstractFileWatcherPrivate(fileUrl, qq)
 {
+    fmDebug() << "Vault: Creating file watcher private for URL:" << fileUrl.toString();
 }
 
 bool VaultFileWatcherPrivate::start()
 {
+    fmDebug() << "Vault: Starting file watcher";
     return proxyStaging && proxyStaging->startWatcher();
 }
 
 bool VaultFileWatcherPrivate::stop()
 {
+    fmDebug() << "Vault: Stopping file watcher";
     return proxyStaging && proxyStaging->stopWatcher();
 }
